@@ -55,13 +55,13 @@ void AppModeHelper::setup(ActionManager* am,
 						  QMap<QString, QPointer<ScrAction> > *scLA,
 						  QMap<QString, QPointer<ScrAction> > *scRPA)
 {
-	a_actMgr=am;
-	a_scrActions=scrA;
-	a_scrRecentFileActions=scrRFA;
-	a_scrWindowsActions=sWA;
-	a_scrScrapActions=scSA;
-	a_scrLayersActions=scLA;
-	a_scrRecentPasteActions=scRPA;
+	a_actMgr = am;
+	a_scrActions = scrA;
+	a_scrRecentFileActions = scrRFA;
+	a_scrWindowsActions = sWA;
+	a_scrScrapActions = scSA;
+	a_scrLayersActions = scLA;
+	a_scrRecentPasteActions = scRPA;
 }
 
 void AppModeHelper::resetApplicationMode(int newMode)
@@ -77,7 +77,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 	assert(newMode < submodeFirstSubmode);
 
 	//If no doc and we end here, just reset the tool actions
-	if (doc==nullptr)
+	if (doc == nullptr)
 	{
 		resetApplicationMode(newMode);
 		return;
@@ -88,7 +88,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 	setModeActionsPerMode(newMode);
 
 	int oldMode = doc->appMode;
-	PageItem *currItem=nullptr;
+	PageItem *currItem = nullptr;
 	if (!doc->m_Selection->isEmpty())
 		currItem = doc->m_Selection->itemAt(0);
 
@@ -104,7 +104,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 		ss->set("CHANGE_MODE");
 		ss->set("OLD", oldMode);
 		ss->set("NEW", newMode);
-		UndoManager::instance()->action(currItem,ss);
+		UndoManager::instance()->action(currItem, ss);
 	}
 	doc->appMode = newMode ;
 	//disable text action which work only text frame in edit mode
@@ -202,6 +202,9 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 		case modeUnlinkFrames:
 			doc->regionsChanged()->update(QRect());
 			break;
+		default:
+			//No doc open?
+			break;
 	}
 
 	switch (newMode)
@@ -347,7 +350,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 					scmw->charPalette->setEnabled(true, currItem);
 					(*a_scrActions)["insertSampleText"]->setEnabled(true);
 					(*a_scrActions)["toolsEditWithStoryEditor"]->setEnabled(true);
-					PageItem *i2 = currItem->asTable()->activeCell().textFrame();
+					const PageItem *i2 = currItem->asTable()->activeCell().textFrame();
 					enableTextActions(true, i2->currentCharStyle().font().scName());
 					setTextEditMode(true);
 					a_actMgr->saveActionShortcutsPreEditMode();
@@ -447,7 +450,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 		(*a_scrActions)["editDeselectAll"]->setEnabled(SelectedType != -1);
 	}
 	(*a_scrActions)["itemDetachTextFromPath"]->setEnabled(false);
-	bool isImageFrame = SelectedType==PageItem::ImageFrame;
+	bool isImageFrame = SelectedType == PageItem::ImageFrame;
 	(*a_scrActions)["itemUpdateImage"]->setEnabled(isImageFrame && (currItem->imageIsAvailable || currItem->isLatexFrame()));
 	(*a_scrActions)["itemAdjustFrameToImage"]->setEnabled(isImageFrame && currItem->imageIsAvailable);
 	(*a_scrActions)["itemAdjustImageToFrame"]->setEnabled(isImageFrame && currItem->imageIsAvailable);
@@ -463,7 +466,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 	(*a_scrActions)["editPasteContentsAbs"]->setEnabled(isImageFrame);
 	(*a_scrActions)["editEditWithImageEditor"]->setEnabled(isImageFrame && currItem->imageIsAvailable && currItem->isRaster);
 	(*a_scrActions)["editEditRenderSource"]->setEnabled(isImageFrame && currItem && (currItem->isLatexFrame() || currItem->isOSGFrame()));
-	(*a_scrActions)["itemAdjustFrameHeightToText"]->setEnabled(SelectedType==PageItem::TextFrame && currItem->itemText.length() >0);
+	(*a_scrActions)["itemAdjustFrameHeightToText"]->setEnabled(SelectedType == PageItem::TextFrame && currItem->itemText.length() > 0);
 	if (!isImageFrame)
 	{
 		(*a_scrActions)["itemImageIsVisible"]->setChecked(false);
@@ -677,7 +680,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["toolsRotate"]->setEnabled(!inAnEditMode);
 			if (doc->appMode == modeEditTable)
 			{
-				PageItem *i2 = currItem->asTable()->activeCell().textFrame();
+				const PageItem *i2 = currItem->asTable()->activeCell().textFrame();
 				enableTextActions(true, i2->currentCharStyle().font().scName());
 				(*a_scrActions)["insertSampleText"]->setEnabled(true);
 				(*a_scrActions)["toolsEditWithStoryEditor"]->setEnabled(true);
@@ -839,7 +842,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 		bool hPoly = true;
 		for (int i = 0; i < docSelectionCount; ++i)
 		{
-			PageItem* it = doc->m_Selection->itemAt(i);
+			const PageItem* it = doc->m_Selection->itemAt(i);
 			if ((!it->isPolygon()) && (!it->isPolyLine()))
 			{
 				hPoly = false;
@@ -935,7 +938,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			if (docSelectionCount > 1)
 			{
 				bool haveSameParent = true;
-				PageItem *firstItem = doc->m_Selection->itemAt(0);
+				const PageItem *firstItem = doc->m_Selection->itemAt(0);
 				for (int i = 1; i < docSelectionCount; ++i)
 				{
 					if (doc->m_Selection->itemAt(i)->Parent != firstItem->Parent)
@@ -969,53 +972,53 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 void AppModeHelper::setModeActionsPerMode(int newMode)
 {
 	//set the actions state based on incoming mode
-	(*a_scrActions)["toolsSelect"]->setChecked(newMode==modeNormal);
-	(*a_scrActions)["toolsInsertTextFrame"]->setChecked(newMode==modeDrawText);
-	(*a_scrActions)["toolsInsertImageFrame"]->setChecked(newMode==modeDrawImage);
-	(*a_scrActions)["toolsInsertTable"]->setChecked(newMode==modeDrawTable2);
-	(*a_scrActions)["toolsInsertShape"]->setChecked(newMode==modeDrawShapes);
-	(*a_scrActions)["toolsInsertPolygon"]->setChecked(newMode==modeDrawRegularPolygon);
-	(*a_scrActions)["toolsInsertArc"]->setChecked(newMode==modeDrawArc);
-	(*a_scrActions)["toolsInsertSpiral"]->setChecked(newMode==modeDrawSpiral);
-	(*a_scrActions)["toolsInsertLine"]->setChecked(newMode==modeDrawLine);
-	(*a_scrActions)["toolsInsertBezier"]->setChecked(newMode==modeDrawBezierLine);
-	(*a_scrActions)["toolsInsertFreehandLine"]->setChecked(newMode==modeDrawFreehandLine);
+	(*a_scrActions)["toolsSelect"]->setChecked(newMode == modeNormal);
+	(*a_scrActions)["toolsInsertTextFrame"]->setChecked(newMode == modeDrawText);
+	(*a_scrActions)["toolsInsertImageFrame"]->setChecked(newMode == modeDrawImage);
+	(*a_scrActions)["toolsInsertTable"]->setChecked(newMode == modeDrawTable2);
+	(*a_scrActions)["toolsInsertShape"]->setChecked(newMode == modeDrawShapes);
+	(*a_scrActions)["toolsInsertPolygon"]->setChecked(newMode == modeDrawRegularPolygon);
+	(*a_scrActions)["toolsInsertArc"]->setChecked(newMode == modeDrawArc);
+	(*a_scrActions)["toolsInsertSpiral"]->setChecked(newMode == modeDrawSpiral);
+	(*a_scrActions)["toolsInsertLine"]->setChecked(newMode == modeDrawLine);
+	(*a_scrActions)["toolsInsertBezier"]->setChecked(newMode == modeDrawBezierLine);
+	(*a_scrActions)["toolsInsertFreehandLine"]->setChecked(newMode == modeDrawFreehandLine);
 	(*a_scrActions)["toolsInsertCalligraphicLine"]->setChecked(newMode == modeDrawCalligraphicLine);
-	(*a_scrActions)["toolsInsertRenderFrame"]->setChecked(newMode==modeDrawLatex);
-	(*a_scrActions)["toolsRotate"]->setChecked(newMode==modeRotation);
-	(*a_scrActions)["toolsZoom"]->setChecked(newMode==modeMagnifier);
-	(*a_scrActions)["toolsEditContents"]->setChecked(newMode==modeEdit);
-	(*a_scrActions)["toolsEditWithStoryEditor"]->setChecked(newMode==modeStoryEditor);
-	(*a_scrActions)["toolsLinkTextFrame"]->setChecked(newMode==modeLinkFrames);
-	(*a_scrActions)["toolsUnlinkTextFrame"]->setChecked(newMode==modeUnlinkFrames);
-//	(*a_scrActions)["toolsUnlinkTextFrameAndCutText"]->setChecked(newMode==modeUnlinkFrames);
-	(*a_scrActions)["toolsEyeDropper"]->setChecked(newMode==modeEyeDropper);
-	(*a_scrActions)["toolsMeasurements"]->setChecked(newMode==modeMeasurementTool);
-	(*a_scrActions)["toolsCopyProperties"]->setChecked(newMode==modeCopyProperties);
-	(*a_scrActions)["toolsPDFPushButton"]->setChecked(newMode==modeInsertPDFButton);
-	(*a_scrActions)["toolsPDFRadioButton"]->setChecked(newMode==modeInsertPDFRadioButton);
-	(*a_scrActions)["toolsPDFTextField"]->setChecked(newMode==modeInsertPDFTextfield);
-	(*a_scrActions)["toolsPDFCheckBox"]->setChecked(newMode==modeInsertPDFCheckbox);
-	(*a_scrActions)["toolsPDFComboBox"]->setChecked(newMode==modeInsertPDFCombobox);
-	(*a_scrActions)["toolsPDFListBox"]->setChecked(newMode==modeInsertPDFListbox);
-	(*a_scrActions)["toolsPDFAnnotText"]->setChecked(newMode==modeInsertPDFTextAnnotation);
-	(*a_scrActions)["toolsPDFAnnotLink"]->setChecked(newMode==modeInsertPDFLinkAnnotation);
+	(*a_scrActions)["toolsInsertRenderFrame"]->setChecked(newMode == modeDrawLatex);
+	(*a_scrActions)["toolsRotate"]->setChecked(newMode == modeRotation);
+	(*a_scrActions)["toolsZoom"]->setChecked(newMode == modeMagnifier);
+	(*a_scrActions)["toolsEditContents"]->setChecked(newMode == modeEdit);
+	(*a_scrActions)["toolsEditWithStoryEditor"]->setChecked(newMode == modeStoryEditor);
+	(*a_scrActions)["toolsLinkTextFrame"]->setChecked(newMode == modeLinkFrames);
+	(*a_scrActions)["toolsUnlinkTextFrame"]->setChecked(newMode == modeUnlinkFrames);
+//	(*a_scrActions)["toolsUnlinkTextFrameAndCutText"]->setChecked(newMode == modeUnlinkFrames);
+	(*a_scrActions)["toolsEyeDropper"]->setChecked(newMode == modeEyeDropper);
+	(*a_scrActions)["toolsMeasurements"]->setChecked(newMode == modeMeasurementTool);
+	(*a_scrActions)["toolsCopyProperties"]->setChecked(newMode == modeCopyProperties);
+	(*a_scrActions)["toolsPDFPushButton"]->setChecked(newMode == modeInsertPDFButton);
+	(*a_scrActions)["toolsPDFRadioButton"]->setChecked(newMode == modeInsertPDFRadioButton);
+	(*a_scrActions)["toolsPDFTextField"]->setChecked(newMode == modeInsertPDFTextfield);
+	(*a_scrActions)["toolsPDFCheckBox"]->setChecked(newMode == modeInsertPDFCheckbox);
+	(*a_scrActions)["toolsPDFComboBox"]->setChecked(newMode == modeInsertPDFCombobox);
+	(*a_scrActions)["toolsPDFListBox"]->setChecked(newMode == modeInsertPDFListbox);
+	(*a_scrActions)["toolsPDFAnnotText"]->setChecked(newMode == modeInsertPDFTextAnnotation);
+	(*a_scrActions)["toolsPDFAnnotLink"]->setChecked(newMode == modeInsertPDFLinkAnnotation);
 #ifdef HAVE_OSG
-	(*a_scrActions)["toolsPDFAnnot3D"]->setChecked(newMode==modeInsertPDF3DAnnotation);
+	(*a_scrActions)["toolsPDFAnnot3D"]->setChecked(newMode == modeInsertPDF3DAnnotation);
 #endif
 }
 
-void AppModeHelper::setActionGroupEnabled(QMap<QString, QPointer<ScrAction> >*ag, bool enabled)
+void AppModeHelper::setActionGroupEnabled(const QMap<QString, QPointer<ScrAction> >* ag, bool enabled)
 {
-	if (ag==nullptr)
+	if (ag == nullptr)
 		return;
-	for( QMap<QString, QPointer<ScrAction> >::Iterator it = ag->begin(); it!=ag->end(); ++it )
-			(*it)->setEnabled(enabled);
+	for (auto it = ag->begin(); it != ag->end(); ++it)
+		(*it)->setEnabled(enabled);
 }
 
 void AppModeHelper::setTextEditMode(bool b)
 {
-	bool b2=!b;
+	bool b2 = !b;
 
 	(*a_scrActions)["itemDuplicate"]->setEnabled(b2);
 	(*a_scrActions)["itemMulDuplicate"]->setEnabled(b2);
@@ -1147,9 +1150,9 @@ void AppModeHelper::setFrameEditMode(bool b)
 	setActionGroupEnabled(a_scrLayersActions, b2);
 }
 
-void AppModeHelper::setSymbolEditMode(bool b, ScribusDoc* doc)
+void AppModeHelper::setSymbolEditMode(bool b, const ScribusDoc* doc)
 {
-	bool b2=!b;
+	bool b2 = !b;
 	(*a_scrActions)["pageInsert"]->setEnabled(b2);
 	(*a_scrActions)["pageImport"]->setEnabled(b2);
 	(*a_scrActions)["pageCopy"]->setEnabled(b2);
@@ -1196,7 +1199,7 @@ void AppModeHelper::setSymbolEditMode(bool b, ScribusDoc* doc)
 #endif
 }
 
-void AppModeHelper::setInlineEditMode(bool b, ScribusDoc *doc)
+void AppModeHelper::setInlineEditMode(bool b, const ScribusDoc *doc)
 {
 	bool b2 = !b;
 	(*a_scrActions)["pageInsert"]->setEnabled(b2);
@@ -1251,9 +1254,9 @@ void AppModeHelper::setInlineEditMode(bool b, ScribusDoc *doc)
 #endif
 }
 
-void AppModeHelper::setMasterPageEditMode(bool b, ScribusDoc* doc)
+void AppModeHelper::setMasterPageEditMode(bool b, const ScribusDoc* doc)
 {
-	bool b2=!b;
+	bool b2 = !b;
 	(*a_scrActions)["pageInsert"]->setEnabled(b2);
 	(*a_scrActions)["pageImport"]->setEnabled(b2);
 	(*a_scrActions)["pageDelete"]->setEnabled(b2);
@@ -1315,12 +1318,12 @@ void AppModeHelper::updateActionPluginsActions(ScribusDoc* doc)
 	int selectedType = -1;
 	if (doc->m_Selection->count() > 0)
 	{
-		PageItem *currItem = doc->m_Selection->itemAt(0);
+		const PageItem *currItem = doc->m_Selection->itemAt(0);
 		selectedType = currItem->itemType();
 	}
 	bool isLayerLocked = doc->layerLocked(doc->activeLayer());
 
-	PluginManager& pluginManager(PluginManager::instance());
+	const PluginManager& pluginManager(PluginManager::instance());
 	QStringList pluginNames(pluginManager.pluginNames(false));
 	ScPlugin* plugin;
 	ScActionPlugin* actionPlug;
@@ -1339,18 +1342,18 @@ void AppModeHelper::updateActionPluginsActions(ScribusDoc* doc)
 		pluginAction = ScCore->primaryMainWindow()->scrActions[actionInfo.name];
 		if (!pluginAction)
 			continue;
-		if (isLayerLocked && !actionInfo.enabledOnStartup)
-			pluginAction->setEnabled(false);
-		else
+		if (!isLayerLocked || actionInfo.enabledOnStartup || actionInfo.exportPlugin)
 			pluginAction->setEnabled(actionPlug->handleSelection(doc, selectedType));
+		else
+			pluginAction->setEnabled(false);
 	}
 }
 
-void AppModeHelper::updateTableMenuActions(ScribusDoc* doc)
+void AppModeHelper::updateTableMenuActions(const ScribusDoc* doc)
 {
 	// Determine state.
 	PageItem* item = doc ? doc->m_Selection->itemAt(0) : nullptr;
-	PageItem_Table* table = (item && item->isTable()) ? item->asTable() : nullptr;
+	const PageItem_Table* table = (item && item->isTable()) ? item->asTable() : nullptr;
 
 	if (!doc || !table)
 	{
@@ -1424,7 +1427,7 @@ void AppModeHelper::changeLayer(ScribusDoc *doc, bool clipScrapHaveData)
 	(*a_scrActions)["toolsInsertArc"]->setEnabled(setter);
 	(*a_scrActions)["toolsInsertSpiral"]->setEnabled(setter);
 	(*a_scrActions)["toolsInsertRenderFrame"]->setEnabled(setter);
-	bool setter2=doc->masterPageMode() ? false : setter;
+	bool setter2 = doc->masterPageMode() ? false : setter;
 	(*a_scrActions)["toolsPDFPushButton"]->setEnabled(setter2);
 	(*a_scrActions)["toolsPDFRadioButton"]->setEnabled(setter2);
 	(*a_scrActions)["toolsPDFTextField"]->setEnabled(setter2);
@@ -1437,7 +1440,7 @@ void AppModeHelper::changeLayer(ScribusDoc *doc, bool clipScrapHaveData)
 	updateActionPluginsActions(doc);
 }
 
-void AppModeHelper::mainWindowHasNewDoc(ScribusDoc *doc, bool clipScrapHaveData)
+void AppModeHelper::mainWindowHasNewDoc(const ScribusDoc *doc, bool clipScrapHaveData)
 {
 	bool layerUnlocked = !doc->layerLocked(doc->activeLayer());
 
@@ -1533,9 +1536,11 @@ void AppModeHelper::mainWindowHasNewDoc(ScribusDoc *doc, bool clipScrapHaveData)
 	(*a_scrActions)["pageCopyToMasterPage"]->setEnabled(true);
 	(*a_scrActions)["pageManageGuides"]->setEnabled(true);
 	(*a_scrActions)["pageManageProperties"]->setEnabled(true);
+
+	enableExperimentalActions(doc);
 }
 
-void AppModeHelper::mainWindowSwitchWin(ScribusDoc *doc)
+void AppModeHelper::mainWindowSwitchWin(const ScribusDoc *doc)
 {
 	(*a_scrActions)["fileClose"]->setEnabled(true);
 	if (doc->masterPageMode() || doc->symbolEditMode() || doc->inlineEditMode())
@@ -1613,6 +1618,8 @@ void AppModeHelper::mainWindowSwitchWin(ScribusDoc *doc)
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(doc->SnapGrid);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(doc->SnapGuides);
 	(*a_scrActions)["viewSnapToElements"]->setChecked(doc->SnapElement);
+	
+	enableExperimentalActions(doc);
 }
 
 void AppModeHelper::mainWindowCloseLastDoc()
@@ -1999,3 +2006,20 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	scMW->layerMenu->setEnabled(false);
 }
 
+void AppModeHelper::enableExperimentalActions(const ScribusDoc *doc)
+{
+	bool setter = doc->usesMarksAndNotes()
+				  || PrefsManager::instance().appPrefs.experimentalFeaturePrefs.notesEnabled;
+	(*a_scrActions)["editMark"]->setEnabled(setter);
+	(*a_scrActions)["editMarks"]->setEnabled(setter);
+	(*a_scrActions)["editNotesStyles"]->setEnabled(setter);
+	(*a_scrActions)["insertMarkAnchor"]->setEnabled(setter);
+	(*a_scrActions)["insertMarkNote"]->setEnabled(setter);
+	(*a_scrActions)["insertMarkItem"]->setEnabled(setter);
+	(*a_scrActions)["insertMark2Mark"]->setEnabled(setter);
+	(*a_scrActions)["insertMarkVariableText"]->setEnabled(setter);
+	ScribusMainWindow *scMW = ScCore->primaryMainWindow();
+	scMW->scrMenuMgr->setMenuEnabled("Marks", setter);
+	scMW->scrMenuMgr->setMenuEnabled("InsertMark", setter);
+}
+
