@@ -355,7 +355,7 @@ void CanvasMode_EditMeshPatch::keyPressEvent(QKeyEvent *e)
 				moveBy=10.0;
 			else if ((buttonModifiers & Qt::ShiftModifier) && (buttonModifiers & Qt::ControlModifier) && !(buttonModifiers & Qt::AltModifier))
 				moveBy=0.01;
-			moveBy/=m_doc->unitRatio();//Lets allow movement by the current doc ratio, not only points
+			moveBy /= m_doc->unitRatio();//Lets allow movement by the current doc ratio, not only points
 			moveBy /= m_canvas->m_viewMode.scale;
 			PageItem *currItem = m_doc->m_Selection->itemAt(0);
 			switch (kk)
@@ -972,51 +972,51 @@ void CanvasMode_EditMeshPatch::mouseReleaseEvent(QMouseEvent *m)
 	m->accept();
 	if (m_view->editStrokeGradient != 11 && m_currItem->selectedMeshPointX >=0 && m_patchPoint != noPointDefined && UndoManager::undoEnabled())
 	{
-		ScItemState<QPair<MeshPoint,MeshPoint> > *ss = new ScItemState<QPair<MeshPoint,MeshPoint> >(Um::GradPos);
+		auto *ss = new ScOldNewState<MeshPoint>(Um::GradPos);
 		ss->set("MOVE_MESH_PATCH");
-		ss->set("X",m_currItem->selectedMeshPointX);
-		ss->set("Y",m_currItem->selectedMeshPointY);
-		ss->set("ARRAY",false);
+		ss->set("X", m_currItem->selectedMeshPointX);
+		ss->set("Y", m_currItem->selectedMeshPointY);
+		ss->set("ARRAY", false);
 		switch (m_currItem->selectedMeshPointY){
 			case 1:
 				if ((*m_old_mesh) == m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TL)
 				{
 					delete ss;
-					ss=nullptr;
+					ss = nullptr;
 				}
 				else
-					ss->setItem(qMakePair(*m_old_mesh,m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TL));
+					ss->setStates(*m_old_mesh, m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TL);
 				break;
 			case 2:
 				if ((*m_old_mesh) == m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TR)
 				{
 					delete ss;
-					ss=nullptr;
+					ss = nullptr;
 				}
 				else
-					ss->setItem(qMakePair(*m_old_mesh,m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TR));
+					ss->setStates(*m_old_mesh, m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TR);
 				break;
 			case 3:
 				if ((*m_old_mesh) == m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BR)
 				{
 					delete ss;
-					ss=nullptr;
+					ss = nullptr;
 				}
 				else
-					ss->setItem(qMakePair(*m_old_mesh,m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BR));
+					ss->setStates(*m_old_mesh, m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BR);
 				break;
 			case 4:
 				if ((*m_old_mesh) == m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BL)
 				{
 					delete ss;
-					ss=nullptr;
+					ss = nullptr;
 				}
 				else
-					ss->setItem(qMakePair(*m_old_mesh,m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BL));
+					ss->setStates(*m_old_mesh,m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].BL);
 				break;
 		}
 		if (ss)
-			undoManager->action(m_currItem,ss);
+			undoManager->action(m_currItem, ss);
 	}
 	m_currItem = m_doc->m_Selection->itemAt(0);
 	m_currItem->update();
