@@ -34,7 +34,7 @@ for which a new license (GPL+exception) is in place.
 #include "iconmanager.h"
 
 // TODO: We should have a preference for this instead.
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 	static const Qt::KeyboardModifiers CellNavigationModifiers = Qt::AltModifier | Qt::KeypadModifier;
 #else
 	static const Qt::KeyboardModifiers CellNavigationModifiers = Qt::AltModifier;
@@ -481,10 +481,10 @@ void CanvasMode_EditTable::makeLongTextCursorBlink()
 
 void CanvasMode_EditTable::createContextMenu(PageItem *currItem, double mx, double my)
 {
-	ContextMenu* cmen=nullptr;
+	ContextMenu* cmen = nullptr;
 	m_view->setCursor(QCursor(Qt::ArrowCursor));
 	m_view->setObjectUndoMode();
-	if (currItem!=nullptr)
+	if (currItem != nullptr)
 		cmen = new ContextMenu(*(m_doc->m_Selection), m_ScMW, m_doc);
 	else
 		cmen = new ContextMenu(m_ScMW, m_doc, mx, my);
