@@ -201,7 +201,7 @@ void CanvasMode_ImageImport::mousePressEvent(QMouseEvent *m)
 		else
 			view()->ImageAfterDraw = true;
 	}
-	if (m->button() == Qt::MidButton)
+	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
 		if (m->modifiers() & Qt::ControlModifier)
@@ -236,7 +236,7 @@ void CanvasMode_ImageImport::setImage(PageItem *currItem)
 	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 	m_doc->loadPict(fileName, currItem, false, true);
 	// Call to showScaleAndOffset() is now very likely unnecessary
-	// due to mecanisms used to update properties in PP in 1.5.x+
+	// due to mechanisms used to update properties in PP in 1.5.x+
 	// m_ScMW->contentPalette->update(currItem->isImageFrame());
 	m_ScMW->repaint();
 	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
