@@ -402,8 +402,7 @@ void CanvasMode_NodeEdit::mouseReleaseEvent(QMouseEvent *m)
 		double xposOrig = currItem->xPos();
 		double yposOrig = currItem->yPos();
 
-		ScItemState<QPair<FPointArray, FPointArray> > *state = nullptr;
-		state = m_doc->nodeEdit.finishTransaction1(currItem);
+		ScOldNewState<FPointArray> *state = m_doc->nodeEdit.finishTransaction1(currItem);
 		if (m_doc->nodeEdit.hasNodeSelected() && (m_doc->nodeEdit.selectionCount() == 1))
 		{
 			//FIXME:av
@@ -472,7 +471,7 @@ void CanvasMode_NodeEdit::mouseReleaseEvent(QMouseEvent *m)
 		m_view->endGroupTransaction();
 	}
 	//Commit drag created items to undo manager.
-	if (m_doc->m_Selection->itemAt(0)!=nullptr)
+	if (m_doc->m_Selection->itemAt(0) != nullptr)
 	{
 		m_doc->itemAddCommit(m_doc->m_Selection->itemAt(0));
 	}
@@ -728,8 +727,8 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 				currItem->ClipEdited = true;
 				edited = true;
 				m_doc->nodeEdit.setSubMode(NodeEditContext::MOVE_POINT);
-				PageItem* newItem=m_doc->convertItemTo(currItem, PageItem::PolyLine);
-				currItem=newItem;
+				PageItem* newItem = m_doc->convertItemTo(currItem, PageItem::PolyLine);
+				currItem = newItem;
 				m_doc->m_Selection->clear();
 				m_doc->m_Selection->addItem(currItem);
 				emit m_view->PolyOpen();
@@ -1123,8 +1122,8 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						npf = npf.transformPoint(p, false);
 					}
 				}
-
-				//Control Modifier to have parallele shape
+				FPoint npf1(npf);
+				//Control Modifier to have parallel shape
 				if (m->modifiers() == Qt::ControlModifier)
 				{
 					FPointArray cli;
@@ -1132,11 +1131,11 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						cli = currItem->ContourLine;
 					else
 						cli = currItem->PoLine;
-					FPoint npf1(npf);
+					
 					int tmpNode;
 					int curr = (m_doc->nodeEdit.clre() == 0) ? cli.size() - 2 : m_doc->nodeEdit.clre();
 					int prev = (curr + cli.size() - 4) % cli.size();
-					int next = (curr+4) % cli.size();
+					int next = (curr + 4) % cli.size();
 
 					if (std::abs(cli.point(prev).x() - cli.point(curr).x()) < std::abs(cli.point(next).x() - cli.point(curr).x()))
 						tmpNode = next;
@@ -1151,7 +1150,6 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						tmpNode = prev;
 
 					m_doc->nodeEdit.moveClipPoint(currItem, npf);
-
 					m_doc->nodeEdit.setClre(tmpNode);
 
 					if (m_doc->nodeEdit.isContourLine())
@@ -1174,8 +1172,7 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 
 				}
 				m_doc->nodeEdit.moveClipPoint(currItem, npf);
-
-				m_canvas->displayXYHUD(m->globalPos(), npf.x(), npf.y());
+				m_canvas->displayXYHUD(m->globalPos(), npf.x(), npf1.y());
 			}
 			else
 			{
