@@ -20,13 +20,14 @@ class DigesterParser : public QXmlDefaultHandler
 {
 public:
 	DigesterParser(Digester* digester) : dig(digester) {}
-	bool startDocument()
+
+	bool startDocument() override
 	{
 		dig->beginDoc();
 		return true;
 	}
-	bool startElement( const QString& nsURI, const QString& locName, const QString& qName,
-	                   const QXmlAttributes& qattr)
+	bool startElement(const QString& nsURI, const QString& locName, const QString& qName,
+	                  const QXmlAttributes& qattr) override
 	{
 		Xml_attr attr;
 		for (int i=0; i < qattr.count(); ++i)
@@ -35,38 +36,38 @@ public:
 		return true;
 	}
 
-	bool endElement( const QString& nsURI, const QString& locName, const QString& qName)
+	bool endElement(const QString& nsURI, const QString& locName, const QString& qName) override
 	{
 		dig->end(qName);
 		return true;
 	}
 
-	bool characters ( const QString & ch ) 
+	bool characters(const QString& ch) override
 	{
 		dig->chars(ch);
 		return true;
 	}
 
-	bool error(const QXmlParseException& exception)
+	bool error(const QXmlParseException& exception) override
 	{
 		qDebug("error : line %d, column %d, %s\n", exception.lineNumber(), exception.columnNumber(), exception.message().toLocal8Bit().data());
 		return true;
 	}
 
-	bool fatalError(const QXmlParseException& exception)
+	bool fatalError(const QXmlParseException& exception) override
 	{
 		qDebug("fatal error : line %d, column %d, %s\n", exception.lineNumber(), exception.columnNumber(), exception.message().toLocal8Bit().data());
 		return true;
 	}
 
-	bool warning(const QXmlParseException& exception)
+	bool warning(const QXmlParseException& exception) override
 	{
 		qDebug("warning : line %d, column %d, %s\n", exception.lineNumber(), exception.columnNumber(), exception.message().toLocal8Bit().data());
 		return true;
 	}
 
 private:
-	Digester * dig;
+	Digester* dig { nullptr };
 };
 
 void Digester::parseFile(const Xml_string& filename)
