@@ -33,13 +33,13 @@ public:
 	    Writes an XML representation of this object using the default element tag, see below
 	 */
 	virtual void saxx(SaxHandler & ) const = 0;
-	virtual ~SaxIO() {}
+	virtual ~SaxIO() = default;
 	/**
 		Element tag which is usually used to serialize this object. "" means no elem is created by saxx()
 	 */
 	static const Xml_string saxxDefaultElem;
 	/**
-	  Fills the digester with rules wich ensure that an object which was
+	  Fills the digester with rules which ensure that an object which was
 	  saved via saxx() will be reconstructed on top of the digester stack.
 	  The prefix pattern shall be used to create patterns which constrain
 	  the added rules to this context.
