@@ -487,7 +487,7 @@ void gtAction::getFrameStyle(gtFrameStyle *fstyle)
 
 void gtAction::createParagraphStyle(gtParagraphStyle* pstyle)
 {
-	ScribusDoc* currDoc=m_textFrame->doc();
+	ScribusDoc* currDoc = m_textFrame->doc();
 	for (int i = 0; i < currDoc->paragraphStyles().count(); ++i)
 	{
 		if (currDoc->paragraphStyles()[i].name() == pstyle->getName())
@@ -836,7 +836,7 @@ QString gtAction::parseColor(const QString &s)
 
 void gtAction::finalize()
 {
-	if (m_textFrame->doc()->docHyphenator->AutoCheck)
+	if (m_textFrame->doc()->docHyphenator->autoCheck())
 		m_textFrame->doc()->docHyphenator->slotHyphenate(m_textFrame);
 	m_textFrame->doc()->regionsChanged()->update(QRectF());
 	m_textFrame->doc()->changed();
