@@ -404,7 +404,7 @@ bool LoadSavePlugin::readCharStyles(const QString& /*fileName*/, ScribusDoc* /*d
 	return false;
 }
 
-bool LoadSavePlugin::readLineStyles(const QString& /*fileName*/, QHash<QString,multiLine>* /*Sty*/)
+bool LoadSavePlugin::readLineStyles(const QString& /*fileName*/, QHash<QString, MultiLine>* /*Sty*/)
 {
 	return false;
 }
@@ -535,7 +535,7 @@ bool FileFormat::readCharStyles(const QString& fileName, ScribusDoc* doc, StyleS
 	return (plug && load) ? plug->readCharStyles(fileName, doc, docCharStyles) : false;
 }
 
-bool FileFormat::readLineStyles(const QString& fileName, QHash<QString, multiLine> *Sty) const
+bool FileFormat::readLineStyles(const QString& fileName, QHash<QString, MultiLine> *Sty) const
 {
 	return (plug && load) ? plug->readLineStyles(fileName, Sty) : false;
 }
