@@ -30,11 +30,11 @@ public:
 	const CxfTristimulusSpec& tristimulusSpec() const { return m_tristimulusSpec; }
 	
 	bool isValid() const;
-	bool parse(QDomElement& elem);
+	bool parse(const QDomElement& elem);
 	
 	void reset();
 	
-protected:
+private:
 	QString m_id;
 
 	bool m_hasMeasurementSpec { false };
@@ -44,6 +44,6 @@ protected:
 	CxfTristimulusSpec m_tristimulusSpec;
 };
 
-typedef QSharedPointer<CxfColorSpecification> CxfColorSpecificationShPtr;
+using CxfColorSpecificationShPtr = QSharedPointer<CxfColorSpecification>;
 
 #endif
