@@ -42,10 +42,6 @@ PluginManager::PluginManager() :
 {
 }
 
-PluginManager::~PluginManager()
-{
-}
-
 void* PluginManager::loadDLL(const QString& plugin)
 {
 	void* lib = nullptr;
@@ -77,20 +73,20 @@ void* PluginManager::loadDLL(const QString& plugin)
 	return lib;
 }
 
-void* PluginManager::resolveSym(void* plugin, const char* sym)
+QFunctionPointer PluginManager::resolveSym(void* plugin, const char* sym)
 {
-	void* symAddr = nullptr;
+	QFunctionPointer symAddr = nullptr;
 #ifdef HAVE_DLFCN_H
 	const char* error;
 	dlerror();
-	symAddr = dlsym(plugin, sym);
+	symAddr = (QFunctionPointer) dlsym(plugin, sym);
 	if ((error = dlerror()) != nullptr)
 	{
 		qDebug("%s", tr("Cannot find symbol (%1)", "plugin manager").arg(error).toLocal8Bit().data());
 		symAddr = nullptr;
 	}
 #elif defined(DLL_USE_NATIVE_API) && defined(_WIN32)
-	symAddr = (void* ) GetProcAddress((HMODULE) plugin, sym);
+	symAddr = (QFunctionPointer) GetProcAddress((HMODULE) plugin, sym);
 	if (symAddr == nullptr)
 		qDebug("%s", tr("Cannot find symbol (%1)", "plugin manager").arg(sym).toLocal8Bit().data());
 #else
@@ -138,9 +134,9 @@ QString PluginManager::getPluginName(const QString& fileName)
 	if (baseName.endsWith(platformDllExtension()))
 		baseName.chop(1 + platformDllExtension().length());
 	// check name
-	for (int i = 0; i < (int) baseName.length(); i++)
+	for (QChar c : baseName)
 	{
-		if (! baseName[i].isLetterOrNumber() && baseName[i] != '_' )
+		if (!c.isLetterOrNumber() && c != '_' )
 		{
 			qDebug("Invalid character in plugin name for %s; skipping",
 					fileName.toLocal8Bit().data());
@@ -206,11 +202,10 @@ void PluginManager::initPlugs()
 	}
 	/* Re-try the failed plugins again and again until it promote
 	any progress (changes variable is changing ;)) */
-	QMap<QString, int>::Iterator it;
-	while (loaded < allPlugs.count() && changes!=0)
+	while (loaded < allPlugs.count() && changes != 0)
 	{
 		changes = 0;
-		for (it = allPlugs.begin(); it != allPlugs.end(); ++it)
+		for (auto it = allPlugs.begin(); it != allPlugs.end(); ++it)
 		{
 			if (it.value() != 0)
 				continue;
@@ -224,24 +219,22 @@ void PluginManager::initPlugs()
 			}
 		}
 	}
-	if (loaded != allPlugs.count())
+
+	if (ScCore->usingGUI() && (loaded != allPlugs.count()))
 	{
-		if (ScCore->usingGUI())
-		{
-			bool splashShown = ScCore->splashShowing();
-			QString failedStr("<ul>");
-			for (QStringList::Iterator it = failedPlugs.begin(); it != failedPlugs.end(); ++it)
-				failedStr += "<li>" + *it + "</li>";
-			failedStr += "</ul>";
-			if (splashShown)
-				ScCore->showSplash(false);
-			ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning,
-								 "<qt>" + tr("There is a problem loading %1 of %2 plugins. %3 This is probably caused by some kind of dependency issue or old plugins existing in your install directory. If you clean out your install directory and reinstall and this still occurs, please report it on bugs.scribus.net."
-										).arg(allPlugs.count() - loaded).arg(allPlugs.count()).arg(failedStr)
-									 + "</qt>");
-			if (splashShown)
-				ScCore->showSplash(true);
-		}
+		bool splashShown = ScCore->splashShowing();
+		QString failedStr("<ul>");
+		for (const QString& failedPlug :  failedPlugs)
+			failedStr += "<li>" + failedPlug + "</li>";
+		failedStr += "</ul>";
+		if (splashShown)
+			ScCore->showSplash(false);
+		ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning,
+								"<qt>" + tr("There is a problem loading %1 of %2 plugins. %3 This is probably caused by some kind of dependency issue or old plugins existing in your install directory. If you clean out your install directory and reinstall and this still occurs, please report it on bugs.scribus.net."
+									).arg(allPlugs.count() - loaded).arg(allPlugs.count()).arg(failedStr)
+									+ "</qt>");
+		if (splashShown)
+			ScCore->showSplash(true);
 	}
 }
 
@@ -254,14 +247,7 @@ void PluginManager::enablePlugin(PluginData & pda)
 	bool isActionPlugin = false;
 	if (pda.plugin->inherits("ScActionPlugin"))
 	{
-// 		ScActionPlugin* plugin = dynamic_cast<ScActionPlugin*>(pda.plugin);
-// 		Q_ASSERT(plugin);
 		isActionPlugin = true;
-		/*
-		pda.enabled = setupPluginActions(plugin);
-		if (!pda.enabled)
-			failReason = tr("init failed", "plugin load error");
-		*/
 	}
 	else if (pda.plugin->inherits("ScPersistentPlugin"))
 	{
@@ -285,11 +271,11 @@ void PluginManager::enablePlugin(PluginData & pda)
 
 bool PluginManager::setupPluginActions(ScribusMainWindow *mw)
 {
-	Q_CHECK_PTR(mw);
+	if (!mw)
+		return false;
 	ScActionPlugin* plugin = nullptr;
 
-	//mw->scrMenuMgr->addMenuItemString("SEPARATOR", "Extras");
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		if (!it.value().plugin->inherits("ScActionPlugin"))
 		{
@@ -301,6 +287,7 @@ bool PluginManager::setupPluginActions(ScribusMainWindow *mw)
 		//Insert DLL Action into Dictionary with values from plugin interface
 		plugin = qobject_cast<ScActionPlugin*>(it.value().plugin);
 		assert(plugin);
+
 		ScActionPlugin::ActionInfo ai(plugin->actionInfo());
 		ScrAction* action = new ScrAction(ScrAction::ActionDLL, ai.iconPath1, ai.iconPath2, ai.text, ai.keySequence, mw);
 		Q_CHECK_PTR(action);
@@ -331,11 +318,6 @@ bool PluginManager::setupPluginActions(ScribusMainWindow *mw)
 		}
 		else
 		{
-//			QString actionName(ai.menu.toLower()+ai.menuAfterName);
-		//	QString actionName(ai.menuAfterName);
-		//	ScrAction* afterAction = nullptr;
-		//	if (mw->scrActions.contains(actionName))
-		//		afterAction = mw->scrActions[actionName];
 			if ((!ai.subMenuName.isEmpty()) && (!ai.parentMenu.isEmpty()))
 			{
 				if (!mw->scrMenuMgr->menuExists(ai.menu))
@@ -386,11 +368,11 @@ bool PluginManager::setupPluginActions(ScribusMainWindow *mw)
 
 bool PluginManager::setupPluginActions(StoryEditor *sew)
 {
-	Q_CHECK_PTR(sew);
+	if (!sew)
+		return false;
 	ScActionPlugin* plugin = nullptr;
 
-	//sew->seMenuMgr->addMenuSeparator("Extras");
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		if (!it.value().plugin->inherits("ScActionPlugin"))
 			continue;
@@ -399,6 +381,7 @@ bool PluginManager::setupPluginActions(StoryEditor *sew)
 		//Insert DLL Action into Dictionary with values from plugin interface
 		plugin = qobject_cast<ScActionPlugin*>(it.value().plugin);
 		assert(plugin);
+
 		ScActionPlugin::ActionInfo ai(plugin->actionInfo());
 		if (!ai.enabledForStoryEditor)
 			continue;
@@ -423,22 +406,16 @@ bool PluginManager::setupPluginActions(StoryEditor *sew)
 					if (!sew->seMenuMgr->menuExists(ai.seMenu))
 						sew->seMenuMgr->createMenu(ai.seMenu, ai.subMenuName, ai.parentMenu);
 				}
-//				sew->seMenuMgr->addMenuItem(sew->seActions[ai.name], ai.seMenu, true);
 				sew->seMenuMgr->addMenuItemString(ai.name, ai.menu);
 			}
 		}
 		else
 		{
-		//	QString actionName(ai.seMenu.toLower()+ai.menuAfterName);
-		//	ScrAction* afterAction = nullptr;
-		//	if (sew->seActions.contains(actionName))
-		//		afterAction = sew->seActions[actionName];
 			if ((!ai.subMenuName.isEmpty()) && (!ai.parentMenu.isEmpty()))
 			{
 				if (!sew->seMenuMgr->menuExists(ai.seMenu))
 					sew->seMenuMgr->createMenu(ai.seMenu, ai.subMenuName, ai.parentMenu);
 			}
-//			sew->seMenuMgr->addMenuItemAfter(sew->seActions[ai.name], ai.seMenu, true, afterAction);
 			sew->seMenuMgr->addMenuItemStringAfter(ai.name, ai.menuAfterName, ai.menu);
 		}
 	}
@@ -448,9 +425,11 @@ bool PluginManager::setupPluginActions(StoryEditor *sew)
 
 void PluginManager::enableOnlyStartupPluginActions(ScribusMainWindow* mw)
 {
-	Q_CHECK_PTR(mw);
+	if (!mw)
+		return;
+
 	ScActionPlugin* plugin = nullptr;
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		if (!it.value().plugin->inherits("ScActionPlugin"))
 			continue;
@@ -464,22 +443,21 @@ void PluginManager::enableOnlyStartupPluginActions(ScribusMainWindow* mw)
 
 void PluginManager::enablePluginActionsForSelection(ScribusMainWindow* mw)
 {
-	Q_CHECK_PTR(mw);
-	ScribusDoc* doc = mw->doc;
-	if (!doc)
+	if (!mw || !mw->doc)
 		return;
+	ScribusDoc* doc = mw->doc;
 
 	int selectedType = -1;
 	if (doc->m_Selection->count() > 0)
 	{
-		PageItem *currItem = doc->m_Selection->itemAt(0);
+		const PageItem *currItem = doc->m_Selection->itemAt(0);
 		selectedType = currItem->itemType();
 	}
 	bool isLayerLocked = doc->layerLocked(doc->activeLayer());
 
 	ScActionPlugin* actionPlug = nullptr;
 	ScrAction* pluginAction = nullptr;
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		if (!it.value().plugin->inherits("ScActionPlugin"))
 			continue;
@@ -517,8 +495,8 @@ bool PluginManager::DLLexists(const QString& name, bool includeDisabled) const
 
 bool PluginManager::loadPlugin(PluginData& pluginData)
 {
-	typedef int (*getPluginAPIVersionPtr)();
-	typedef ScPlugin* (*getPluginPtr)();
+	using getPluginAPIVersionPtr = int (*)();
+	using getPluginPtr = ScPlugin* (*)();
 	getPluginAPIVersionPtr getPluginAPIVersion;
 	getPluginPtr getPlugin;
 
@@ -566,7 +544,7 @@ bool PluginManager::loadPlugin(PluginData& pluginData)
 
 void PluginManager::cleanupPlugins()
 {
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		if (!it.value().enabled)
 			continue;
@@ -576,7 +554,7 @@ void PluginManager::cleanupPlugins()
 
 void PluginManager::finalizePlug(PluginData & pluginData)
 {
-	typedef void (*freePluginPtr)(ScPlugin* plugin);
+	using freePluginPtr = void (*)(ScPlugin* plugin);
 	if (pluginData.plugin)
 	{
 		if (pluginData.enabled)
@@ -605,7 +583,14 @@ void PluginManager::disablePlugin(PluginData & pda)
 		assert(plugin);
 		plugin->cleanupPlugin();
 		// FIXME: Correct way to delete action?
-		delete ScCore->primaryMainWindow()->scrActions[plugin->actionInfo().name];
+		auto& scrActions = ScCore->primaryMainWindow()->scrActions;
+		auto actionIt = scrActions.find(plugin->actionInfo().name);
+		if (actionIt != scrActions.end())
+		{
+			QPointer<ScrAction>& delAction = actionIt.value();
+			delete delAction.data();
+			scrActions.erase(actionIt);
+		}
 	}
 	else if (pda.plugin->inherits("ScPersistentPlugin"))
 	{
@@ -658,7 +643,7 @@ void PluginManager::languageChange()
 	ScPlugin* plugin = nullptr;
 	ScActionPlugin* ixplug = nullptr;
 	ScrAction* pluginAction = nullptr;
-	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
+	for (auto it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
 		plugin = it.value().plugin;
 		if (!plugin)
