@@ -118,6 +118,8 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 	resecls["qrcode"] = "L,Q,M,H";
 	resvers["gs1qrcode"] = resvers["qrcode"];
 	resecls["gs1qrcode"] = resecls["qrcode"];
+	resvers["gs1dlqrcode"] = resvers["qrcode"];
+	resecls["gs1dlqrcode"] = resecls["qrcode"];
 	resvers["hibcqrcode"] = resvers["qrcode"];
 	resecls["hibcqrcode"] = resecls["qrcode"];
 	resvers["microqrcode"] = "M1,M2,M3,M4";
@@ -126,6 +128,8 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 	resecls["datamatrix"] = "";
 	resvers["gs1datamatrix"] = resvers["datamatrix"];
 	resecls["gs1datamatrix"] = resvers["datamatrix"];
+	resvers["gs1dldatamatrix"] = resvers["datamatrix"];
+	resecls["gs1dldatamatrix"] = resvers["datamatrix"];
 	resvers["hibcdatamatrix"] = resvers["datamatrix"];
 	resecls["hibcdatamatrix"] = resecls["datamatrix"];
 	resvers["azteccode"] = "1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32";
@@ -153,9 +157,9 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 
 
 	// Which options checkboxes are enabled for each encoder
-	QStringList includetextAvail = encoderlist;
-	foreach (const QString& enc, includetextAvail)
-		resincludetextAvail[enc] = true;
+	// Check whether `includetext` option is available for each encoder
+	for(const QString &enc : encoderlist)
+		resincludetextAvail[enc] = resexops[enc].contains("includetext");
 
 	QStringList guardwhitespaceAvail;
 	guardwhitespaceAvail << "ean13" << "ean8" << "isbn" << "ismn" << "issn" << "ean13composite" << "ean8composite";
@@ -205,7 +209,8 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 	familyItems.insert(familyName, bcNames);
 
 	bcNames.clear();
-	bcNames << "GS1-14" << "GS1 Data Matrix" << "GS1 QR Code" << "GS1-128" << "ITF-14" << "SSCC-18";
+	bcNames << "GS1-14" << "GS1 Data Matrix" << "GS1 QR Code" << "GS1-128" << "ITF-14" << "SSCC-18"
+			<< "GS1 Digital Link QR Code" << "GS1 Digital Link Data Matrix";
 	familyName = tr("Supply Chain");
 	familyList.append(familyName);
 	familyItems.insert(familyName, bcNames);
@@ -332,7 +337,7 @@ BarcodeGenerator::~BarcodeGenerator()
 
 void BarcodeGenerator::updateOptions()
 {
-	QString enc=map[ui.bcCombo->currentText()].command;
+	QString enc = map[ui.bcCombo->currentText()].command;
 
 	ui.formatLabel->setText(resvlbl.contains(enc) ? resvlbl[enc] + ":" : "Version:");
 	ui.formatCombo->blockSignals(true);
@@ -598,7 +603,7 @@ void BarcodeGenerator::updateUIFromOptionsText()
 	ui.eccCombo->blockSignals(true);
 	if (ui.optionsEdit->text().contains(rxe))
 	{
-		int idx=ui.eccCombo->findText(rxe.cap(1));
+		int idx = ui.eccCombo->findText(rxe.cap(1));
 		if (idx == -1)
 			idx = 0;
 		ui.eccCombo->setCurrentIndex(idx);
@@ -790,7 +795,7 @@ void BarcodeGenerator::paintBarcode()
 	QString coloropts("barcolor=%1 showbackground backgroundcolor=%2 textcolor=%3");
 	coloropts = coloropts.arg(lnColor.name().replace('#', ""), bgColor.name().replace('#', ""), txtColor.name().replace('#', ""));
 
-	QString opts=ui.optionsEdit->text() + " " + coloropts;
+	QString opts = ui.optionsEdit->text() + " " + coloropts;
 
 	// Assemble PS from encoder and requirement bodies
 	QString psCommand = "%!PS-Adobe-2.0 EPSF-2.0\n";
@@ -817,7 +822,11 @@ void BarcodeGenerator::paintBarcode()
 				"end\n"
 				);
 	QString comm("20 10 moveto <%1> <%2> /%3 /uk.co.terryburton.bwipp findresource exec\n");
-	QString bcdata(ui.codeEdit->text().toLatin1().toHex());
+	QString bcString = ui.codeEdit->text();
+	QByteArray bcLatin1 = ui.codeEdit->text().toLatin1();
+	QByteArray bcUtf8 = ui.codeEdit->text().toUtf8();
+	QByteArray bcArray = (bcString != QString::fromLatin1(bcLatin1)) ? ("\xef\xbb\xbf" + bcUtf8) : bcLatin1;
+	QString bcdata(bcArray.toHex());
 	QString bcopts(opts.toLatin1().toHex());
 	comm = comm.arg(bcdata, bcopts, map[ui.bcCombo->currentText()].command);
 	psCommand.append(comm);
