@@ -965,7 +965,7 @@ QDomElement SVGExPlug::processPolyItem(PageItem *item, const QString& trans, con
 				ob2.setAttribute("style", "fill:none;" + drS);
 		}
 		ob.appendChild(ob2);
-		multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 		for (int it = ml.size()-1; it > -1; it--)
 		{
 			if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
@@ -994,7 +994,7 @@ QDomElement SVGExPlug::processLineItem(PageItem *item, const QString& trans, con
 	{
 		ob = m_domDoc.createElement("g");
 		ob.setAttribute("transform", trans);
-		multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 		for (int i = ml.size()-1; i > -1; i--)
 		{
 			if ((ml[i].Color != CommonStrings::None) && (ml[i].Width != 0))
@@ -1129,7 +1129,7 @@ QDomElement SVGExPlug::processImageItem(PageItem *item, const QString& trans, co
 	}
 	else
 	{
-		multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 		for (int it = ml.size()-1; it > -1; it--)
 		{
 			if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
@@ -1321,7 +1321,7 @@ QDomElement SVGExPlug::processTextItem(PageItem *item, const QString& trans, con
 		}
 		else
 		{
-			multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+			MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 			for (int it = ml.size()-1; it > -1; it--)
 			{
 				if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
@@ -1359,7 +1359,7 @@ QDomElement SVGExPlug::processTextItem(PageItem *item, const QString& trans, con
 		}
 		else
 		{
-			multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+			MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 			for (int it = ml.size()-1; it > -1; it--)
 			{
 				if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
@@ -1520,7 +1520,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 			}
 			else
 			{
-				multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+				MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 				if (ml[ml.size()-1].Width != 0.0)
 					arrowTrans.scale(ml[ml.size()-1].Width, ml[ml.size()-1].Width);
 			}
@@ -1545,7 +1545,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 					}
 					else
 					{
-						multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+						MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 						if (ml[ml.size()-1].Width != 0.0)
 							arrowTrans.scale(ml[ml.size()-1].Width, ml[ml.size()-1].Width);
 					}
@@ -1642,7 +1642,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 		}
 		else
 		{
-			multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+			MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 			if (ml[0].Color != CommonStrings::None)
 			{
 				ob = m_domDoc.createElement("path");
@@ -1685,7 +1685,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 			}
 			else
 			{
-				multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+				MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 				if (ml[ml.size()-1].Width != 0.0)
 					arrowTrans.scale(ml[ml.size() - 1].Width, ml[ml.size() - 1].Width);
 			}
@@ -1709,7 +1709,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 					}
 					else
 					{
-						multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+						MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 						if (ml[ml.size() - 1].Width != 0.0)
 							arrowTrans.scale(ml[ml.size() - 1].Width, ml[ml.size() - 1].Width);
 					}
@@ -1806,7 +1806,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 		}
 		else
 		{
-			multiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
+			MultiLine ml = m_Doc->docLineStyles[item->NamedLStyle];
 			if (ml[0].Color != CommonStrings::None)
 			{
 				ob = m_domDoc.createElement("path");
