@@ -23,7 +23,7 @@ for which a new license (GPL+exception) is in place.
 class QIODevice;
 
 class  ColorList;
-class  multiLine;
+class  MultiLine;
 class  PageItem_NoteFrame;
 class  ScLayer;
 class  ScribusDoc;
@@ -71,7 +71,7 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 		bool loadPage(const QString& fileName, int pageNumber, bool Mpage, const QString& renamedPageName = QString()) override;
 		bool readStyles(const QString& fileName, ScribusDoc* doc, StyleSet<ParagraphStyle> &docParagraphStyles) override;
 		bool readCharStyles(const QString& fileName, ScribusDoc* doc, StyleSet<CharStyle> &docCharStyles) override;
-		bool readLineStyles(const QString& fileName, QHash<QString, multiLine> *Sty) override;
+		bool readLineStyles(const QString& fileName, QHash<QString, MultiLine> *Sty) override;
 		bool readColors(const QString& fileName, ColorList & colors) override;
 		bool readPageCount(const QString& fileName, int *num1, int *num2, QStringList & masterPageNames) override;
 		void getReplacedFontData(bool & getNewReplacement, QMap<QString,QString> &getReplacedFonts, QList<ScFace> &getDummyScFaces) override;
@@ -143,7 +143,7 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 		bool readItemTableCell(PageItem_Table* item, ScXmlStreamReader& reader, ScribusDoc *doc) const;
 		bool readLatexInfo(PageItem_LatexFrame* item, ScXmlStreamReader& reader) const;
 		void readLayers(ScLayer& layer, const ScXmlStreamAttributes& attrs) const;
-		bool readMultiline(multiLine& ml, ScXmlStreamReader& reader) const;
+		bool readMultiline(MultiLine& ml, ScXmlStreamReader& reader) const;
 		bool readObject(ScribusDoc* doc, ScXmlStreamReader& reader, const ReadObjectParams& loadParams, ItemInfo& info);
 		bool readPage(ScribusDoc* doc, ScXmlStreamReader& reader);
 		bool readPageItemAttributes(PageItem* item, ScXmlStreamReader& reader) const;
