@@ -14,6 +14,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <QApplication>
 #include <QByteArray>
+#include <QDebug>
 #include <QScopedPointer>
 
 #include "scribusdoc.h"
@@ -459,6 +460,7 @@ void ODTIm::parseStyles(const QDomElement &sp, const QString& type)
 					currStyle.textStrikeThrough = AttributeValue(spe.attribute("style:text-line-through-style", ""));
 					currStyle.textShadow = AttributeValue(spe.attribute("fo:text-shadow", ""));
 					currStyle.fontVariant = AttributeValue(spe.attribute("fo:font-variant", ""));
+					currStyle.language = AttributeValue(spe.attribute("fo:language", ""));
 				}
 			}
 			if (spd.attribute("style:family") == "paragraph")
@@ -539,6 +541,7 @@ void ODTIm::parseStyles(const QDomElement &sp, const QString& type)
 					currStyle.textStrikeThrough = AttributeValue(spe.attribute("style:text-line-through-style", ""));
 					currStyle.textShadow = AttributeValue(spe.attribute("fo:text-shadow", ""));
 					currStyle.fontVariant = AttributeValue(spe.attribute("fo:font-variant", ""));
+					currStyle.language = AttributeValue(spe.attribute("fo:language", ""));
 				}
 			}
 			currStyle.displayName = AttributeValue(spd.attribute("style:display-name", ""));
@@ -571,7 +574,7 @@ void ODTIm::parseStyles(const QDomElement &sp, const QString& type)
 								parentName = pStyle.displayName.value;
 						}
 					}
-					if (m_prefixName)
+					if (m_prefixName && (parentName != CommonStrings::DefaultParagraphStyle))
 						newStyle.setParent(m_item->itemName() + "_" + parentName);
 					else
 						newStyle.setParent(parentName);
@@ -676,6 +679,27 @@ void ODTIm::parseTextSpan(const QDomElement &elem, PageItem* item, const Paragra
 	if (textStyleName.length() > 0)
 	{
 		resolveStyle(odtStyle, textStyleName);
+		if (m_Styles.contains(textStyleName))
+		{
+			DrawStyle currStyle = m_Styles[textStyleName];
+			if (currStyle.styleOrigin.value == "styles")
+			{
+				QString charStyleName;
+				if (m_prefixName)
+				{
+					charStyleName = m_item->itemName() + "_" + textStyleName;
+					if (currStyle.displayName.valid)
+						charStyleName = m_item->itemName() + "_" + currStyle.displayName.value;
+				}
+				else
+				{
+					charStyleName = textStyleName;
+					if (currStyle.displayName.valid)
+						charStyleName = currStyle.displayName.value;
+				}
+				cStyle.setParent(charStyleName);
+			}
+		}
 		m_textStylesStack.push(textStyleName);
 	}
 	
@@ -969,6 +993,7 @@ void ODTIm::applyCharacterStyle(CharStyle &tmpCStyle, const ObjStyleODT &oStyle)
 	tmpCStyle.setFontSize(oStyle.fontSize * 10);
 	tmpCStyle.setFillColor(oStyle.CurrColorText);
 	tmpCStyle.setBackColor(oStyle.CurrColorBText);
+	tmpCStyle.setLanguage(oStyle.language);
 	StyleFlag styleEffects = tmpCStyle.effects();
 	if ((oStyle.textPos.startsWith("super")) || (oStyle.textPos.startsWith("sub")))
 	{
@@ -1126,6 +1151,8 @@ void ODTIm::resolveStyle(ObjStyleODT &tmpOStyle, const QString& styleName)
 			actStyle.breakAfter = AttributeValue(currStyle.breakAfter.value);
 		if (currStyle.breakBefore.valid)
 			actStyle.breakBefore = AttributeValue(currStyle.breakBefore.value);
+		if (currStyle.language.valid)
+			actStyle.language = AttributeValue(currStyle.language.value);
 	}
 
 	if (actStyle.textBackgroundColor.valid)
@@ -1312,6 +1339,8 @@ void ODTIm::resolveStyle(ObjStyleODT &tmpOStyle, const QString& styleName)
 		tmpOStyle.breakAfter = actStyle.breakAfter.value;
 	if (actStyle.breakBefore.valid)
 		tmpOStyle.breakBefore = actStyle.breakBefore.value;
+	if (actStyle.language.valid)
+		tmpOStyle.language = actStyle.language.value;
 }
 
 double ODTIm::parseUnit(const QString &unit)
