@@ -349,7 +349,7 @@ bool CdrPlug::convert(const QString& fn)
 			{
 				ScribusMainWindow* mw=(m_Doc==0) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 				qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-				ScMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project http://www.documentliberation.org"));
+				ScMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project https://www.documentliberation.org"));
 				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
 			}*/
 			return false;
@@ -372,7 +372,7 @@ bool CdrPlug::convert(const QString& fn)
 			{
 				ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 				QGuiApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
-				ScMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project http://www.documentliberation.org"));
+				ScMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project https://www.documentliberation.org"));
 				QGuiApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 			}
 			return false;
