@@ -181,7 +181,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
 	if (showProgress)
 	{
-		ScribusMainWindow* mw = (m_Doc==nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
+		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
 		QStringList barNames, barTexts;
 		barNames << "GI";
@@ -3389,12 +3389,12 @@ PageItem* CgmPlug::itemAdd(PageItem::ItemType itemType, PageItem::ItemFrameType
 				PageItem *ite = m_Doc->Items->at(z);
 				ite->setPattern(patternTable[patternIndex]);
 				ScPattern pat = m_Doc->docPatterns[patternTable[patternIndex]];
-				double patSX = 100;
-				double patSY = 100;
+				double patSX = 1.0;
+				double patSY = 1.0;
 				if (patternScaleX > -1)
-					patSX = patternScaleX / pat.width * 100;
+					patSX = patternScaleX / pat.width;
 				if (patternScaleY > -1)
-					patSY = patternScaleY / pat.height * 100;
+					patSY = patternScaleY / pat.height;
 				ite->setPatternTransform(patSX, patSY, 0, 0, 0, 0.0, 0.0);
 				ite->GrType = Gradient_Pattern;
 			}
@@ -3418,12 +3418,12 @@ PageItem* CgmPlug::itemAdd(PageItem::ItemType itemType, PageItem::ItemFrameType
 				PageItem *ite = m_Doc->Items->at(z);
 				ite->setPattern(patternTable[patternIndex]);
 				ScPattern pat = m_Doc->docPatterns[patternTable[patternIndex]];
-				double patSX = 100;
-				double patSY = 100;
+				double patSX = 1.0;
+				double patSY = 1.0;
 				if (patternScaleX > -1)
-					patSX = patternScaleX / pat.width * 100;
+					patSX = patternScaleX / pat.width;
 				if (patternScaleY > -1)
-					patSY = patternScaleY / pat.height * 100;
+					patSY = patternScaleY / pat.height;
 				ite->setPatternTransform(patSX, patSY, 0, 0, 0, 0.0, 0.0);
 				ite->GrType = Gradient_Pattern;
 			}
