@@ -160,7 +160,7 @@ private:
 	QPointF     getPoint(QDataStream &ds, bool size);
 	quint32     getColor(QDataStream &ds);
 	void        setWTransform(const QTransform& mm, quint32 how);
-	QPointF     intersectBoundingRect(PageItem *item, QLineF gradientVector);
+	QPointF     intersectBoundingRect(PageItem *item, const QLineF& gradientVector);
 	void        finishItem(PageItem* ite, bool fill = true);
 	void        invalidateClipGroup();
 	void        createClipGroup();
@@ -296,41 +296,47 @@ private:
 	QHash<quint32, emfStyle> emfStyleMap;
 	QHash<quint32, emfStyle> emfStyleMapEMP;
 	QList<PageItem*> Elements;
-	PageItem* clipGroup;
-	double docWidth;
-	double docHeight;
-	double baseX, baseY;
-	double docX;
-	double docY;
-	double dpiX;
-	double dpiY;
-	quint32 EmfPdpiX, EmfPdpiY;
-	quint32 m_records;
-	int recordCount;
-	qint32 viewPextendX, viewPextendY;
-	qint32 winPextendX, winPextendY;
-	qint32 winOrigX, winOrigY;
+	PageItem* clipGroup { nullptr };
+	double docWidth { 0.0 };
+	double docHeight { 0.0 };
+	double baseX { 0.0 };
+	double baseY { 0.0 };
+	double docX { 0.0 };
+	double docY { 0.0 };
+	double dpiX { 0.0 };
+	double dpiY { 0.0 };
+	quint32 EmfPdpiX { 0 };
+	quint32 EmfPdpiY { 0 };
+	quint32 m_records { 0 };
+	int recordCount { 0 };
+	qint32 viewPextendX { 0 };
+	qint32 viewPextendY { 0 };
+	qint32 winPextendX { 0 };
+	qint32 winPextendY { 0 };
+	qint32 winOrigX { 0 };
+	qint32 winOrigY { 0 };
 	QRectF bBoxDev;
 	QRectF bBoxMM;
 	QStringList importedColors;
 	QStringList importedPatterns;
-	bool interactive;
-	MultiProgressDialog * progressDialog;
-	bool cancel;
-	ScribusDoc* m_Doc;
-	Selection* tmpSel;
-	int importerFlags;
+	bool interactive { false };
+	MultiProgressDialog * progressDialog { nullptr };
+	bool cancel { false };
+	ScribusDoc* m_Doc { nullptr };
+	Selection* tmpSel { nullptr };
+	int importerFlags { 0 };
 	QString baseFile;
-	bool inPath;
-	bool inEMFPlus;
-	bool emfPlusDual;
-	bool emfMixed;
-	float emfPlusScale;
-	bool SerializableObject_Valid;
+	bool inPath { false };
+	bool inEMFPlus { false };
+	bool emfPlusDual { false };
+	bool emfMixed { false };
+	float emfPlusScale { 0.0 };
+	bool SerializableObject_Valid { false };
 	ScImageEffectList m_Effects;
-	quint32 m_ObjSize;
-	quint32 m_currObjSize;
-	quint16 m_objID;
+	quint32 m_ObjSize { 0 };
+	quint32 m_currObjSize { 0 };
+	quint16 m_objID { 0 };
+
 public slots:
 	void cancelRequested() { cancel = true; }
 };
