@@ -11,409 +11,13 @@ for which a new license (GPL+exception) is in place.
 	email                : Franz.Schmid@altmuehlnet.de
  ***************************************************************************/
 
-
-#if 0
-#include <QByteArray>
-#include <QCursor>
-#include <QDrag>
-#include <QFile>
-#include <QList>
-#include <QMessageBox>
-#include <QMimeData>
-#include <QRegExp>
-#include <QStack>
-#include <QDebug>
-
+#include <climits>
 #include <cstdlib>
-#include "importpages.h"
-#include "../revenge/rawpainter.h"
-#include <libetonyek/libetonyek.h>
-#include <boost/shared_ptr.hpp>
-
-#include "commonstrings.h"
-#include "ui/customfdialog.h"
-#include "fileloader.h"
-#include "loadsaveplugin.h"
-#include "ui/missing.h"
-#include "ui/multiprogressdialog.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
-#include "prefsmanager.h"
-#include "prefstable.h"
-#include "ui/propertiespalette.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
-#include "scconfig.h"
-#include "scmimedata.h"
-#include "scpaths.h"
-#include "scpattern.h"
-#include "scribus.h"
-#include "scribusXml.h"
-#include "scribuscore.h"
-#include "scribusview.h"
-#include "sctextstream.h"
-#include "selection.h"
-#include "undomanager.h"
-#include "util.h"
-#include "util_formats.h"
-#include "util_math.h"
-
-extern SCRIBUS_API ScribusQApp * ScQApp;
-
-PagesPlug::PagesPlug(ScribusDoc* doc, int flags) :
-	baseX(0.0),
-	baseY(0.0),
-	docWidth(0.0),
-	docHeight(0.0),
-	cancel(false),
-	firstPage(false),
-	pagecount(0),
-	mpagecount(0),
-	topMargin(0.0),
-	leftMargin(0.0),
-	rightMargin(0.0),
-	bottomMargin(0.0),
-	pgCols(0.0),
-	pgGap(0.0)
-{
-	tmpSel = new Selection(this, false);
-	m_Doc = doc;
-	importerFlags = flags;
-	interactive = (flags & LoadSavePlugin::lfInteractive);
-	progressDialog = nullptr;
-}
-
-QImage PagesPlug::readThumbnail(QString fName)
-{
-	QFileInfo fi = QFileInfo(fName);
-	double b, h;
-	b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
-	docWidth = b;
-	docHeight = h;
-	progressDialog = nullptr;
-	m_Doc = new ScribusDoc();
-	m_Doc->setup(0, 1, 1, 1, 1, "Custom", "Custom");
-	m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
-	m_Doc->addPage(0);
-	m_Doc->setGUI(false, ScCore->primaryMainWindow(), 0);
-	baseX = m_Doc->currentPage()->xOffset();
-	baseY = m_Doc->currentPage()->yOffset();
-	Elements.clear();
-	m_Doc->setLoading(true);
-	m_Doc->DoDrawing = false;
-	m_Doc->scMW()->setScriptRunning(true);
-	QString CurDirP = QDir::currentPath();
-	QDir::setCurrent(fi.path());
-	if (convert(fName))
-	{
-		tmpSel->clear();
-		QDir::setCurrent(CurDirP);
-		if (Elements.count() > 1)
-			m_Doc->groupObjectsList(Elements);
-		m_Doc->DoDrawing = true;
-		m_Doc->m_Selection->delaySignalsOn();
-		QImage tmpImage;
-		if (Elements.count() > 0)
-		{
-			for (int dre=0; dre<Elements.count(); ++dre)
-			{
-				tmpSel->addItem(Elements.at(dre), true);
-			}
-			tmpSel->setGroupRect();
-			double xs = tmpSel->width();
-			double ys = tmpSel->height();
-			tmpImage = Elements.at(0)->DrawObj_toImage(500);
-			tmpImage.setText("XSize", QString("%1").arg(xs));
-			tmpImage.setText("YSize", QString("%1").arg(ys));
-		}
-		m_Doc->scMW()->setScriptRunning(false);
-		m_Doc->setLoading(false);
-		m_Doc->m_Selection->delaySignalsOff();
-		delete m_Doc;
-		return tmpImage;
-	}
-	else
-	{
-		QDir::setCurrent(CurDirP);
-		m_Doc->DoDrawing = true;
-		m_Doc->scMW()->setScriptRunning(false);
-		delete m_Doc;
-	}
-	return QImage();
-}
-
-bool PagesPlug::import(QString fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
-{
-	QString fName = fNameIn;
-	bool success = false;
-	interactive = (flags & LoadSavePlugin::lfInteractive);
-	importerFlags = flags;
-	cancel = false;
-	double b, h;
-	bool ret = false;
-	QFileInfo fi = QFileInfo(fName);
-	if ( !ScCore->usingGUI() )
-	{
-		interactive = false;
-		showProgress = false;
-	}
-	if ( showProgress )
-	{
-		ScribusMainWindow* mw=(m_Doc==0) ? ScCore->primaryMainWindow() : m_Doc->scMW();
-		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
-		QStringList barNames, barTexts;
-		barNames << "GI";
-		barTexts << tr("Analyzing File:");
-		QList<bool> barsNumeric;
-		barsNumeric << false;
-		progressDialog->addExtraProgressBars(barNames, barTexts, barsNumeric);
-		progressDialog->setOverallTotalSteps(3);
-		progressDialog->setOverallProgress(0);
-		progressDialog->setProgress("GI", 0);
-		progressDialog->show();
-		connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		qApp->processEvents();
-	}
-	else
-		progressDialog = nullptr;
-/* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
-	if (progressDialog)
-	{
-		progressDialog->setOverallProgress(1);
-		qApp->processEvents();
-	}
-	if (b == 0.0)
-		b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	if (h == 0.0)
-		h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
-	docWidth = b;
-	docHeight = h;
-	baseX = 0;
-	baseY = 0;
-	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
-	{
-		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
-		m_Doc->addPage(0);
-		m_Doc->view()->addPage(0, true);
-		baseX = 0;
-		baseY = 0;
-	}
-	else
-	{
-		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
-		{
-			m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
-			ScCore->primaryMainWindow()->HaveNewDoc();
-			ret = true;
-			baseX = 0;
-			baseY = 0;
-			baseX = m_Doc->currentPage()->xOffset();
-			baseY = m_Doc->currentPage()->yOffset();
-		}
-	}
-	if ((!ret) && (interactive))
-	{
-		baseX = m_Doc->currentPage()->xOffset();
-		baseY = m_Doc->currentPage()->yOffset();
-	}
-	if ((ret) || (!interactive))
-	{
-		if (docWidth > docHeight)
-			m_Doc->setPageOrientation(1);
-		else
-			m_Doc->setPageOrientation(0);
-		m_Doc->setPageSize("Custom");
-	}
-	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
-	Elements.clear();
-	m_Doc->setLoading(true);
-	m_Doc->DoDrawing = false;
-	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->updatesOn(false);
-	m_Doc->scMW()->setScriptRunning(true);
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
-	QString CurDirP = QDir::currentPath();
-	QDir::setCurrent(fi.path());
-	if (convert(fName))
-	{
-		tmpSel->clear();
-		QDir::setCurrent(CurDirP);
-		if ((Elements.count() > 1) && (!(importerFlags & LoadSavePlugin::lfCreateDoc)))
-			m_Doc->groupObjectsList(Elements);
-		m_Doc->DoDrawing = true;
-		m_Doc->scMW()->setScriptRunning(false);
-		m_Doc->setLoading(false);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((Elements.count() > 0) && (!ret) && (interactive))
-		{
-			if (flags & LoadSavePlugin::lfScripted)
-			{
-				bool loadF = m_Doc->isLoading();
-				m_Doc->setLoading(false);
-				m_Doc->changed();
-				m_Doc->setLoading(loadF);
-				if (!(flags & LoadSavePlugin::lfLoadAsPattern))
-				{
-					m_Doc->m_Selection->delaySignalsOn();
-					for (int dre=0; dre<Elements.count(); ++dre)
-					{
-						m_Doc->m_Selection->addItem(Elements.at(dre), true);
-					}
-					m_Doc->m_Selection->delaySignalsOff();
-					m_Doc->m_Selection->setGroupRect();
-					if (m_Doc->view() != nullptr)
-						m_Doc->view()->updatesOn(true);
-				}
-			}
-			else
-			{
-				m_Doc->DragP = true;
-				m_Doc->DraggedElem = 0;
-				m_Doc->DragElements.clear();
-				m_Doc->m_Selection->delaySignalsOn();
-				for (int dre=0; dre<Elements.count(); ++dre)
-				{
-					tmpSel->addItem(Elements.at(dre), true);
-				}
-				tmpSel->setGroupRect();
-				ScElemMimeData* md = ScriXmlDoc::writeToMimeData(m_Doc, tmpSel);
-				m_Doc->itemSelection_DeleteItem(tmpSel);
-				m_Doc->view()->updatesOn(true);
-				if (importedPatterns.count() != 0)
-				{
-					for (int cd = 0; cd < importedPatterns.count(); cd++)
-					{
-						m_Doc->docPatterns.remove(importedPatterns[cd]);
-					}
-				}
-				if (importedColors.count() != 0)
-				{
-					for (int cd = 0; cd < importedColors.count(); cd++)
-					{
-						m_Doc->PageColors.remove(importedColors[cd]);
-					}
-				}
-				m_Doc->m_Selection->delaySignalsOff();
-				// We must copy the TransationSettings object as it is owned
-				// by handleObjectImport method afterwards
-				TransactionSettings* transacSettings = new TransactionSettings(trSettings);
-				m_Doc->view()->handleObjectImport(md, transacSettings);
-				m_Doc->DragP = false;
-				m_Doc->DraggedElem = 0;
-				m_Doc->DragElements.clear();
-			}
-		}
-		else
-		{
-			m_Doc->changed();
-			m_Doc->reformPages();
-			if (!(flags & LoadSavePlugin::lfLoadAsPattern))
-				m_Doc->view()->updatesOn(true);
-		}
-		success = true;
-	}
-	else
-	{
-		QDir::setCurrent(CurDirP);
-		m_Doc->DoDrawing = true;
-		m_Doc->scMW()->setScriptRunning(false);
-		m_Doc->view()->updatesOn(true);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-	}
-	if (interactive)
-		m_Doc->setLoading(false);
-	//CB If we have a gui we must refresh it if we have used the progressbar
-	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
-	{
-		if ((showProgress) && (!interactive))
-			m_Doc->view()->DrawNew();
-	}
-	qApp->restoreOverrideCursor();
-	return success;
-}
-
-PagesPlug::~PagesPlug()
-{
-	if (progressDialog)
-		delete progressDialog;
-	delete tmpSel;
-}
-
-using boost::shared_ptr;
-using libetonyek::EtonyekDocument;
-
-bool PagesPlug::convert(QString fn)
-{
-	importedColors.clear();
-	importedPatterns.clear();
-
-	QFile file(fn);
-	if (!file.exists())
-	{
-		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
-		return false;
-	}
-
-	shared_ptr<librevenge::RVNGInputStream> input;
-	if (librevenge::RVNGDirectoryStream::isDirectory(QFile::encodeName(fn).data()))
-		input.reset(new librevenge::RVNGDirectoryStream(QFile::encodeName(fn).data()));
-	else
-	input.reset(new librevenge::RVNGFileStream(QFile::encodeName(fn).data()));
-	EtonyekDocument::Type type = EtonyekDocument::TYPE_UNKNOWN;
-	const EtonyekDocument::Confidence confidence = EtonyekDocument::isSupported(input.get(), &type);
-	if ((EtonyekDocument::CONFIDENCE_NONE == confidence) || (EtonyekDocument::TYPE_PAGES != type))
-	{
-		qDebug() << "ERROR: Unsupported file format!";
-		return false;
-	}
-	if (EtonyekDocument::CONFIDENCE_SUPPORTED_PART == confidence)
-	  input.reset(librevenge::RVNGDirectoryStream::createForParent(QFile::encodeName(fn).data()));
-	RawPainterPres painter(m_Doc, baseX, baseY, docWidth, docHeight, importerFlags, &Elements, &importedColors, &importedPatterns, tmpSel, "pages");
-	if (!EtonyekDocument::parse(input.get(), &painter))
-	{
-		qDebug() << "ERROR: Import failed!";
-		if (progressDialog)
-			progressDialog->close();
-		if (importerFlags & LoadSavePlugin::lfCreateDoc)
-		{
-			ScribusMainWindow* mw=(m_Doc==0) ? ScCore->primaryMainWindow() : m_Doc->scMW();
-			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-			QMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project http://www.documentliberation.org"), 1, 0, 0);
-			qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
-		}
-		return false;
-	}
-	if (Elements.count() == 0)
-	{
-		if (importedColors.count() != 0)
-		{
-			for (int cd = 0; cd < importedColors.count(); cd++)
-			{
-				m_Doc->PageColors.remove(importedColors[cd]);
-			}
-		}
-		if (importedPatterns.count() != 0)
-		{
-			for (int cd = 0; cd < importedPatterns.count(); cd++)
-			{
-				m_Doc->docPatterns.remove(importedPatterns[cd]);
-			}
-		}
-	}
-	if (progressDialog)
-		progressDialog->close();
-	return true;
-}
-#else
+#include <limits>
 
 #include <QByteArray>
 #include <QCursor>
+#include <QDebug>
 #include <QDrag>
 #include <QFile>
 #include <QList>
@@ -421,21 +25,14 @@ bool PagesPlug::convert(QString fn)
 #include <QRegExp>
 #include <QStack>
 #include <QUrl>
-#include <QDebug>
 
 #if defined(_MSC_VER) && !defined(_USE_MATH_DEFINES)
 #define _USE_MATH_DEFINES
 #endif
 
-#include <cstdlib>
-#include <climits>
-#include <limits>
-
-#include "commonstrings.h"
-
 #include "importpages.h"
 
-
+#include "commonstrings.h"
 #include "loadsaveplugin.h"
 #include "pageitem_table.h"
 #include "pagesize.h"
@@ -467,24 +64,8 @@ bool PagesPlug::convert(QString fn)
 #include "util_math.h"
 
 PagesPlug::PagesPlug(ScribusDoc* doc, int flags)
-	: baseX(0.0),
-	  baseY(0.0),
-	  docWidth(0.0),
-	  docHeight(0.0),
-	  m_Doc(doc),
-	  importerFlags(flags),
-	  progressDialog(nullptr),
-	  cancel(false),
-	  firstPage(false),
-	  pagecount(0),
-	  mpagecount(0),
-	  topMargin(0.0),
-	  leftMargin(0.0),
-	  rightMargin(0.0),
-	  bottomMargin(0.0),
-	  pgCols(0.0),
-	  pgGap(0.0),
-	  uz(nullptr)
+	: m_Doc(doc),
+	  importerFlags(flags)
 {
 	tmpSel = new Selection(this, false);
 	interactive = (flags & LoadSavePlugin::lfInteractive);
@@ -613,7 +194,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	firstPage = true;
 	pagecount = 1;
 	mpagecount = 0;
-	QFileInfo fi = QFileInfo(fNameIn);
+	QFileInfo fi(fNameIn);
 	if ( !ScCore->usingGUI() )
 	{
 		interactive = false;
@@ -633,14 +214,14 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 		progressDialog->setProgress("GI", 0);
 		progressDialog->show();
 		connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	else
 		progressDialog = nullptr;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	/* Set default Page to size defined in Preferences */
 	docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
@@ -668,12 +249,12 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 			baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
 		}
 	}
-	if ((!ret) && (interactive))
+	if (!ret && interactive)
 	{
 		baseX = m_Doc->currentPage()->xOffset();
 		baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
 	}
-	if ((ret) || (!interactive))
+	if (ret || !interactive)
 	{
 		if (docWidth > docHeight)
 			m_Doc->setPageOrientation(1);
@@ -689,7 +270,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
 	if (convert(fNameIn))
@@ -701,8 +282,8 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((Elements.count() > 0) && (!ret) && (interactive))
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		if ((Elements.count() > 0) && !ret && interactive)
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -777,7 +358,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 		m_Doc->scMW()->setScriptRunning(false);
 		if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 			m_Doc->view()->updatesOn(true);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		success = false;
 	}
 	if (interactive)
@@ -785,10 +366,10 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	//CB If we have a gui we must refresh it if we have used the progressbar
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-		if ((showProgress) && (!interactive))
+		if (showProgress && !interactive)
 			m_Doc->view()->DrawNew();
 	}
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 	return success;
 }
 
@@ -808,7 +389,7 @@ bool PagesPlug::convert(const QString& fn)
 	{
 		progressDialog->setOverallProgress(2);
 		progressDialog->setLabel("GI", tr("Generating Items"));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 
 	uz = new ScZipHandler();
@@ -837,6 +418,7 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 	QDomDocument designMapDom;
 	if (!uz->read(designMap, f))
 		return false;
+
 	if (compressed)
 	{
 		QTemporaryFile *tmpFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
@@ -859,7 +441,7 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 		}
 		delete tmpFile;
 	}
-	QString errorMsg = "";
+	QString errorMsg;
 	int errorLine = 0;
 	int errorColumn = 0;
 	if (!designMapDom.setContent(f, &errorMsg, &errorLine, &errorColumn))
@@ -1152,7 +734,6 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											QString type = spg.attribute("xsi:type");
 											if (type == "sfa:calibrated-white-color-type")
 											{
-											//	currStyle.fontColor = AttributeValue("White");
 												QColor c;
 												double w = spg.attribute("sfa:w", "1").toDouble();
 												c.setRgbF(w, w, w);
@@ -1160,7 +741,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 												tmp.fromQColor(c);
 												tmp.setSpotColor(false);
 												tmp.setRegistrationColor(false);
-												QString newColorName = "FromPages"+c.name();
+												QString newColorName = "FromPages" + c.name();
 												QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 												if (fNam == newColorName)
 													importedColors.append(newColorName);
@@ -1191,7 +772,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 												tmp.setColorF(c, m, y, k);
 												tmp.setSpotColor(false);
 												tmp.setRegistrationColor(false);
-												QString newColorName = "FromPages"+tmp.name();
+												QString newColorName = "FromPages" + tmp.name();
 												QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 												if (fNam == newColorName)
 													importedColors.append(newColorName);
@@ -1261,7 +842,6 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											QString type = spg.attribute("xsi:type");
 											if (type == "sfa:calibrated-white-color-type")
 											{
-											//	currStyle.fontColor = AttributeValue("White");
 												QColor c;
 												double w = spg.attribute("sfa:w", "1").toDouble();
 												c.setRgbF(w, w, w);
@@ -1269,7 +849,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 												tmp.fromQColor(c);
 												tmp.setSpotColor(false);
 												tmp.setRegistrationColor(false);
-												QString newColorName = "FromPages"+c.name();
+												QString newColorName = "FromPages" + c.name();
 												QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 												if (fNam == newColorName)
 													importedColors.append(newColorName);
@@ -1392,7 +972,6 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 													currStyle.strokeOpacity  = AttributeValue(QString("%1").arg(1.0 - sph.attribute("sfa:a", "1").toDouble()));
 													if (type == "sfa:calibrated-white-color-type")
 													{
-													//	currStyle.CurrColorStroke = AttributeValue("White");
 														QColor c;
 														double w = sph.attribute("sfa:w", "1").toDouble();
 														c.setRgbF(w, w, w);
@@ -1400,7 +979,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 														tmp.fromQColor(c);
 														tmp.setSpotColor(false);
 														tmp.setRegistrationColor(false);
-														QString newColorName = "FromPages"+c.name();
+														QString newColorName = "FromPages" + c.name();
 														QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 														if (fNam == newColorName)
 															importedColors.append(newColorName);
@@ -1431,7 +1010,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 														tmp.setColorF(c, m, y, k);
 														tmp.setSpotColor(false);
 														tmp.setRegistrationColor(false);
-														QString newColorName = "FromPages"+tmp.name();
+														QString newColorName = "FromPages" + tmp.name();
 														QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 														if (fNam == newColorName)
 															importedColors.append(newColorName);
@@ -1453,7 +1032,6 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											currStyle.fillOpacity = AttributeValue(QString("%1").arg(1.0 - spg.attribute("sfa:a", "1").toDouble()));
 											if (type == "sfa:calibrated-white-color-type")
 											{
-											//	currStyle.CurrColorFill = AttributeValue("White");
 												QColor c;
 												double w = spg.attribute("sfa:w", "1").toDouble();
 												c.setRgbF(w, w, w);
@@ -1461,7 +1039,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 												tmp.fromQColor(c);
 												tmp.setSpotColor(false);
 												tmp.setRegistrationColor(false);
-												QString newColorName = "FromPages"+c.name();
+												QString newColorName = "FromPages" + c.name();
 												QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 												if (fNam == newColorName)
 													importedColors.append(newColorName);
@@ -1492,7 +1070,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 												tmp.setColorF(c, m, y, k);
 												tmp.setSpotColor(false);
 												tmp.setRegistrationColor(false);
-												QString newColorName = "FromPages"+tmp.name();
+												QString newColorName = "FromPages" + tmp.name();
 												QString fNam = m_Doc->PageColors.tryAddColor(newColorName, tmp);
 												if (fNam == newColorName)
 													importedColors.append(newColorName);
@@ -2242,4 +1820,3 @@ void PagesPlug::finishItem(PageItem* item, ObjState &obState)
 		item->setDashes(pattern);
 	}*/
 }
-#endif
