@@ -417,7 +417,8 @@ bool WMFImport::loadWMF( QBuffer &buffer )
 		st >> pheader.reserved;
 		st >> pheader.checksum;
 		checksum = calcCheckSum( &pheader );
-		if ( pheader.checksum!=checksum ) m_IsPlaceable = false;
+		if (pheader.checksum != checksum)
+			m_IsPlaceable = false;
 
 		m_Dpi = pheader.inch;
 		m_BBox.setLeft( pheader.bbox.left );
@@ -431,7 +432,7 @@ bool WMFImport::loadWMF( QBuffer &buffer )
 			cerr << "WMF Placeable Header ( " << static_cast<int>(sizeof( pheader ) ) << "):" << endl;
 			cerr << "  bbox=( " << m_BBox.left() << "; " << m_BBox.top() << "; " << m_BBox.width() << "; " << m_BBox.height() << ")" << endl;
 			cerr << "  inch=" << pheader.inch << endl;
-			cerr << "  checksum=" << pheader.checksum << "( " << (pheader.checksum==checksum?"ok":"wrong") << " )" << endl;
+			cerr << "  checksum=" << pheader.checksum << "( " << (pheader.checksum == checksum ? "ok" : "wrong") << " )" << endl;
 		}
 	}
 	else buffer.seek( 0 );
@@ -449,7 +450,7 @@ bool WMFImport::loadWMF( QBuffer &buffer )
 	st >> eheader.rclFrame.right;
 	st >> eheader.rclFrame.bottom;
 	st >> eheader.dSignature;
-	m_IsEnhanced = ( eheader.dSignature==ENHMETA_SIGNATURE );
+	m_IsEnhanced = (eheader.dSignature == ENHMETA_SIGNATURE);
 	if ( m_IsEnhanced ) // is it really enhanced ?
 	{
 		st >> eheader.nVersion;
@@ -572,7 +573,7 @@ bool WMFImport::importWMF(const TransactionSettings& trSettings, int flags)
 	{
 		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
 		{
-			m_Doc=ScCore->primaryMainWindow()->doFileNew(fabs(width), fabs(height), 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
+			m_Doc = ScCore->primaryMainWindow()->doFileNew(fabs(width), fabs(height), 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
 			ScCore->primaryMainWindow()->HaveNewDoc();
 			ret = true;
 		}
@@ -1097,7 +1098,7 @@ void WMFImport::setBkColor( QList<PageItem*>& /*items*/, long, const short* para
 
 void WMFImport::setBkMode(QList<PageItem*>& /*items*/, long, const short* params )
 {
-	if ( params[ 0 ]==1 ) 
+	if (params[0] == 1)
 		m_context.setBackgroundMode( Qt::TransparentMode );
 	else 
 		m_context.setBackgroundMode( Qt::OpaqueMode );
@@ -1110,7 +1111,7 @@ void WMFImport::saveDC( QList<PageItem*>& /*items*/, long, const short* )
 
 void WMFImport::restoreDC( QList<PageItem*>& /*items*/, long, const short *params )
 {
-	for ( int i=0; i > params[ 0 ] ; i-- )
+	for (int i = 0; i > params[0]; i--)
 		m_context.restore();
 }
 
