@@ -22,7 +22,6 @@ PyObject *scribus_newdocument(PyObject* /* self */, PyObject* args)
 {
 	double topMargin, bottomMargin, leftMargin, rightMargin;
 	double pageWidth, pageHeight;
-//	int orientation, firstPageNr, unit, pagesType, facingPages, firstPageOrder, numPages;
 	int orientation, firstPageNr, unit, pagesType, firstPageOrder, numPages;
 
 	PyObject *p, *m;
@@ -113,6 +112,20 @@ PyObject *scribus_newdoc(PyObject* /* self */, PyObject* args)
 	return PyLong_FromLong(static_cast<long>(ret));
 }
 
+PyObject *scribus_getbleeds(PyObject */* self */, PyObject* /*args*/)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	const MarginStruct& bleeds = ScCore->primaryMainWindow()->doc->bleedsVal();
+
+	return Py_BuildValue("(dddd)",
+		PointToValue(bleeds.left()),
+		PointToValue(bleeds.right()),
+		PointToValue(bleeds.top()),
+		PointToValue(bleeds.bottom()));
+}
+
 PyObject *scribus_setbleeds(PyObject */* self */, PyObject *args)
 {
 	double lr, tpr, btr, rr;
@@ -131,6 +144,20 @@ PyObject *scribus_setbleeds(PyObject */* self */, PyObject *args)
 	Py_RETURN_NONE;
 }
 
+PyObject* scribus_getmargins(PyObject*/* self */, PyObject* /*args*/)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	const MarginStruct& margins = ScCore->primaryMainWindow()->doc->marginsVal();
+
+	return Py_BuildValue("(dddd)",
+		PointToValue(margins.left()),
+		PointToValue(margins.right()),
+		PointToValue(margins.top()),
+		PointToValue(margins.bottom()));
+}
+
 PyObject *scribus_setmargins(PyObject* /* self */, PyObject* args)
 {
 	double lr, tpr, btr, rr;
@@ -151,6 +178,18 @@ PyObject *scribus_setmargins(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
+PyObject* scribus_getbaseline(PyObject* /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	const GuidesPrefs& guides = ScCore->primaryMainWindow()->doc->guidesPrefs();
+
+	return Py_BuildValue("(dd)",
+		PointToValue(guides.valueBaselineGrid),
+		PointToValue(guides.offsetBaselineGrid));
+}
+
 PyObject *scribus_setbaseline(PyObject* /* self */, PyObject* args)
 {
 	double grid, offset;
@@ -171,14 +210,13 @@ PyObject *scribus_setbaseline(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-
 PyObject *scribus_closedoc(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
 		return nullptr;
 	ScCore->primaryMainWindow()->doc->setModified(false);
 	bool ret = ScCore->primaryMainWindow()->slotFileClose();
-	qApp->processEvents();
+	QApplication::processEvents();
 	return PyLong_FromLong(static_cast<long>(ret));
 }
 
@@ -280,7 +318,7 @@ PyObject *scribus_getinfo(PyObject* /* self */)
 		return PyUnicode_FromString("");
 	}
 
-	DocumentInformation& docInfo = ScCore->primaryMainWindow()->doc->documentInfo();
+	const DocumentInformation& docInfo = ScCore->primaryMainWindow()->doc->documentInfo();
 	return Py_BuildValue("(sss)",
 				docInfo.author().toUtf8().data(),
 				docInfo.title().toUtf8().data(),
@@ -311,6 +349,43 @@ PyObject *scribus_getunit(PyObject* /* self */)
 	return PyLong_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->unitIndex()));
 }
 
+PyObject *scribus_pointstodocunit(PyObject* /* self */, PyObject *args)
+{
+    double points;
+    if (!PyArg_ParseTuple(args, "d", &points))
+        return nullptr;
+    if (!checkHaveDocument())
+        return nullptr;
+
+    return Py_BuildValue("d", PointToValue(points));
+}
+
+PyObject *scribus_docunittopoints(PyObject* /* self */, PyObject *args)
+{
+    double value;
+    if (!PyArg_ParseTuple(args, "d", &value))
+        return nullptr;
+    if (!checkHaveDocument())
+        return nullptr;
+
+    return Py_BuildValue("d", ValueToPoint(value));
+}
+
+PyObject *scribus_stringvaluetopoints(PyObject* /* self */, PyObject *args)
+{
+    PyESString strValue;
+    if (!PyArg_ParseTuple(args, "es", "utf-8", strValue.ptr()))
+        return nullptr;
+
+    QString qv = QString::fromUtf8(strValue.c_str());
+
+    int uIdx = unitIndexFromString(qv);
+    double value = unitValueFromString(qv);
+    double points = value / unitGetRatioFromIndex(uIdx);
+
+    return Py_BuildValue("d", points);
+}
+
 PyObject *scribus_loadstylesfromfile(PyObject* /* self */, PyObject *args)
 {
 	PyESString fileName;
@@ -358,7 +433,7 @@ PyObject *scribus_masterpagenames(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
 		return nullptr;
-	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+	const ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 
 	PyObject* names = PyList_New(currentDoc->MasterPages.count());
 	QMap<QString,int>::const_iterator it(currentDoc->MasterNames.constBegin());
@@ -448,8 +523,8 @@ PyObject *scribus_getmasterpage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	e--;
 
-	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
-	if ((e < 0) || (e > static_cast<int>(currentDoc->Pages->count())-1))
+	const ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: '%1'.","python error").arg(e+1).toLocal8Bit().constData());
 		return nullptr;
@@ -473,7 +548,7 @@ PyObject* scribus_applymasterpage(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(PyExc_ValueError, QObject::tr("Master page does not exist: '%1'","python error").arg(masterPageName).toLocal8Bit().constData());
 		return nullptr;
 	}
-	if ((page < 1) || (page > static_cast<int>(currentDoc->Pages->count())))
+	if ((page < 1) || (page > currentDoc->Pages->count()))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: %1.","python error").arg(page).toLocal8Bit().constData());
 		return nullptr;
@@ -498,9 +573,12 @@ void cmddocdocwarnings()
 	  << scribus_closemasterpage__doc__
 	  << scribus_createmasterpage__doc__
 	  << scribus_deletemasterpage__doc__
-	  << scribus_editmasterpage__doc__ 
+	  << scribus_editmasterpage__doc__
+	  << scribus_getbaseline__doc__ 
+	  << scribus_getbleeds__doc__ 
 	  << scribus_getdocname__doc__
 	  << scribus_getinfo__doc__
+	  << scribus_getmargins__doc__
 	  << scribus_getmasterpage__doc__
 	  << scribus_getunit__doc__ 
 	  << scribus_havedoc__doc__
