@@ -347,7 +347,7 @@ static int PDFfile_init(PDFfile *self, PyObject * /*args*/, PyObject * /*kwds*/)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	PDFOptions& pdfOptions = currentDoc->pdfOptions();
 
-	// Defaut save into file
+	// Default save into file
 	QString tf = pdfOptions.fileName;
 	if (tf.isEmpty())
 	{
@@ -1049,13 +1049,13 @@ static int PDFfile_seteffval(PDFfile *self, PyObject *value, void * /*closure*/)
 		PyObject *tmp = PyList_GetItem(value, i);
 		if (!PyList_Check(tmp))
 		{
-			PyErr_SetString(PyExc_TypeError, "elemets of 'effval' must be list of five integers.");
+			PyErr_SetString(PyExc_TypeError, "elements of 'effval' must be list of five integers.");
 			return -1;
 		}
 		int j = PyList_Size(tmp);
 		if (j != 6)
 		{
-			PyErr_SetString(PyExc_TypeError, "elemets of 'effval' must have exactly six integers.");
+			PyErr_SetString(PyExc_TypeError, "elements of 'effval' must have exactly six integers.");
 			return -1;
 		}
 		for (--j; j > -1; --j)
@@ -1327,7 +1327,7 @@ static int PDFfile_setopenAction(PDFfile *self, PyObject *value, void * /*closur
 
 static char *effval_doc = const_cast<char*>(
 "List of effection values for each saved page.\n"
-"It is list of list of six integers. Those int has followin meaning:\n\t"
+"It is a list of list of six integers. Those int has the following meaning:\n\t"
 "- Length of time the page is shown before the presentation\n\tstarts on the selected page. (1-3600)\n\t"
 "- Length of time the effect runs. (1 - 3600)\n\t\tA shorter time will speed up the effect,\n\t\ta longer one will slow it down\n\t"
 "- Type of the display effect\n\t\t0 - No Effect\n\t\t1 - Blinds\n\t\t2 - Box\n\t\t3 - Dissolve\n\t\t4 - Glitter\n\t\t5 - Split\n\t\t6 - Wipe\n\t"
@@ -1337,7 +1337,7 @@ static char *effval_doc = const_cast<char*>(
 
 static char *lpival_doc = const_cast<char*>(
 "Rendering Settings for individual colors.\n\n"
-"This is list of values for each color\n"
+"This is a list of values for each color\n"
 "Color values have structure [siii] which stand for:\n\t"
 "s - Color name ('Black', 'Cyan', 'Magenta', 'Yellow')\n\t"
 "i - Frequency (10 to 1000)\n\t"
@@ -1492,7 +1492,7 @@ static PyObject *PDFfile_save(PDFfile *self)
 		PyObject *ti = PyList_GetItem(self->effval, i);
 		if (!ti)
 			continue;
-		// Do I Need to check if every PyInt_AsLong and PyList_GetItem funtion succeed???
+		// Do I Need to check if every PyInt_AsLong and PyList_GetItem function succeed???
 		t.pageEffectDuration = PyInt_AsLong(PyList_GetItem(ti, 0));
 		t.pageViewDuration = PyInt_AsLong(PyList_GetItem(ti, 1));
 		t.effectType = PyInt_AsLong(PyList_GetItem(ti, 2));
