@@ -46,8 +46,8 @@ class ScribusDoc;
 
 struct shapeData
 {
-	int width;
-	int height;
+	int width { 0 };
+	int height { 0 };
 	QString name;
 	FPointArray path;
 };
@@ -63,7 +63,7 @@ public:
 	void updateShapeList();
 
 	QHash<QString, shapeData> shapes;
-	ScribusMainWindow *scMW;
+	ScribusMainWindow *scMW { nullptr };
 
 public slots:
 	void HandleContextMenu(QPoint);
@@ -74,13 +74,12 @@ signals:
 	void objectDropped();
 
 protected:
-	bool viewportEvent(QEvent *event);
-	void keyPressEvent(QKeyEvent *e);
-	void dragEnterEvent(QDragEnterEvent *e);
-	void dragMoveEvent(QDragMoveEvent *e);
-	void dropEvent(QDropEvent *e);
-	void startDrag(Qt::DropActions supportedActions);
-
+	bool viewportEvent(QEvent *event) override;
+	void keyPressEvent(QKeyEvent *e) override;
+	void dragEnterEvent(QDragEnterEvent *e) override;
+	void dragMoveEvent(QDragMoveEvent *e) override;
+	void dropEvent(QDropEvent *e) override;
+	void startDrag(Qt::DropActions supportedActions) override;
 
 private:
 	ScListWidgetDelegate* delegate;
