@@ -366,7 +366,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 						qmatrix.scale(-1, 1);
 					if (mirrorY)
 						qmatrix.scale(1, -1);
-					QImage pat = *doc->docPatterns[currItem->pattern()].getPattern();
+					QImage pat = doc->docPatterns[currItem->pattern()].getPattern();
 					QBrush brush(pat);
 					brush.setTransform(qmatrix);
 					pItem->setBrush(brush);
@@ -398,7 +398,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 					qmatrix.scale(-1, 1);
 				if (mirrorY)
 					qmatrix.scale(1, -1);
-				QImage pat = *doc->docPatterns[currItem->strokePattern()].getPattern();
+				QImage pat = doc->docPatterns[currItem->strokePattern()].getPattern();
 				QBrush brush(pat);
 				brush.setTransform(qmatrix);
 				pItem->setPen(QPen(brush, currItem->lineWidth(), currItem->lineStyle(), currItem->lineEnd(), currItem->lineJoin()));
