@@ -487,7 +487,7 @@ void ScPageOutput::drawItem_Post(PageItem* item, ScPainterExBase* painter)
 			}
 			else
 			{
-				multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+				MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 				for (int it = ml.size() - 1; it > -1; it--)
 				{
 					const SingleLine& sl = ml[it];
@@ -873,7 +873,7 @@ void ScPageOutput::drawItem_Line(PageItem_Line* item, ScPainterExBase* painter,
 	else
 	{
 		painter->setStrokeMode(ScPainterExBase::Solid);
-		multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 		for (int it = ml.size() - 1; it > -1; it--)
 		{
 			const SingleLine& sl = ml[it];
@@ -1190,7 +1190,7 @@ void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* p
 	}
 	else
 	{
-		multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 		for (int it = ml.size() - 1; it > -1; it--)
 		{
 			const SingleLine& sl = ml[it];
@@ -1362,7 +1362,7 @@ void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* paint
 	}
 	else
 	{
-		multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 		for (int it = ml.size() - 1; it > -1; it--)
 		{
 			const SingleLine& sl = ml[it];
@@ -1442,7 +1442,7 @@ void ScPageOutput::drawItem_Text(PageItem* item, ScPainterExBase* painter, const
 		}
 		else
 		{
-			multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+			MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 			for (int it = ml.size() - 1; it > -1; it--)
 			{
 				const SingleLine& sl = ml[it];
@@ -1500,7 +1500,7 @@ void ScPageOutput::drawArrow(ScPainterExBase* painter, PageItem* item, QTransfor
 	}
 	else
 	{
-		multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 		if (ml[ml.size() - 1].Width != 0.0)
 			arrowTrans.scale(ml[ml.size() - 1].Width, ml[ml.size() - 1].Width);
 	}
@@ -1524,7 +1524,7 @@ void ScPageOutput::drawArrow(ScPainterExBase* painter, PageItem* item, QTransfor
 	}
 	else
 	{
-		multiLine ml = m_doc->docLineStyles[item->NamedLStyle];
+		MultiLine ml = m_doc->docLineStyles[item->NamedLStyle];
 		if (ml[0].Color != CommonStrings::None)
 		{
 			ScColorShade tmp(m_doc->PageColors[ml[0].Color], ml[0].Shade);
