@@ -613,7 +613,7 @@ cairo_pattern_t * ScPainter::getMaskPattern()
 			m_imageQ = m_maskPattern->pattern.copy();
 			if (m_maskMode == 6)
 				m_imageQ.invertPixels(QImage::InvertRgba);
-			m_imageMask = cairo_image_surface_create_for_data (m_imageQ.bits(), CAIRO_FORMAT_ARGB32, m_maskPattern->getPattern()->width(), m_maskPattern->getPattern()->height(), m_maskPattern->getPattern()->width() * 4);
+			m_imageMask = cairo_image_surface_create_for_data (m_imageQ.bits(), CAIRO_FORMAT_ARGB32, m_maskPattern->getPattern().width(), m_maskPattern->getPattern().height(), m_maskPattern->getPattern().width() * 4);
 		}
 		pat = cairo_pattern_create_for_surface(m_imageMask);
 		cairo_pattern_set_extend(pat, CAIRO_EXTEND_REPEAT);
@@ -624,7 +624,7 @@ cairo_pattern_t * ScPainter::getMaskPattern()
 		qmatrix.rotate(m_maskPatternTrans.rotation);
 		qmatrix.shear(-m_maskPatternTrans.skewX, m_maskPatternTrans.skewY);
 		qmatrix.scale(m_maskPatternTrans.scaleX, m_maskPatternTrans.scaleY);
-		qmatrix.scale(m_maskPattern->width / static_cast<double>(m_maskPattern->getPattern()->width()), m_maskPattern->height / static_cast<double>(m_maskPattern->getPattern()->height()));
+		qmatrix.scale(m_maskPattern->width / static_cast<double>(m_maskPattern->getPattern().width()), m_maskPattern->height / static_cast<double>(m_maskPattern->getPattern().height()));
 		if (m_mask_patternMirrorX)
 			qmatrix.scale(-1, 1);
 		if (m_mask_patternMirrorY)
@@ -1077,7 +1077,7 @@ void ScPainter::fillPathHelper()
 	else if (m_fillMode == 3)
 	{
 		cairo_set_antialias(m_cr, CAIRO_ANTIALIAS_NONE);
-		cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)m_pattern->getPattern()->bits(), CAIRO_FORMAT_ARGB32, m_pattern->getPattern()->width(), m_pattern->getPattern()->height(), m_pattern->getPattern()->width() * 4);
+		cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)m_pattern->getPattern().bits(), CAIRO_FORMAT_ARGB32, m_pattern->getPattern().width(), m_pattern->getPattern().height(), m_pattern->getPattern().width() * 4);
 		cairo_pattern_t *m_pat = cairo_pattern_create_for_surface(image2);
 		cairo_pattern_set_extend(m_pat, CAIRO_EXTEND_REPEAT);
 		cairo_pattern_set_filter(m_pat, CAIRO_FILTER_GOOD);
@@ -1087,7 +1087,7 @@ void ScPainter::fillPathHelper()
 		qmatrix.rotate(m_patternTrans.rotation);
 		qmatrix.shear(-m_patternTrans.skewX, m_patternTrans.skewY);
 		qmatrix.scale(m_patternTrans.scaleX, m_patternTrans.scaleY);
-		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
+		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern().width()), m_pattern->height / static_cast<double>(m_pattern->getPattern().height()));
 		if (m_patternMirrorX)
 			qmatrix.scale(-1, 1);
 		if (m_patternMirrorY)
@@ -1243,7 +1243,7 @@ void ScPainter::strokePathHelper()
 	{
 		cairo_push_group(m_cr);
 		cairo_set_antialias(m_cr, CAIRO_ANTIALIAS_NONE);
-		cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)m_pattern->getPattern()->bits(), CAIRO_FORMAT_ARGB32, m_pattern->getPattern()->width(), m_pattern->getPattern()->height(), m_pattern->getPattern()->width() * 4);
+		cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)m_pattern->getPattern().bits(), CAIRO_FORMAT_ARGB32, m_pattern->getPattern().width(), m_pattern->getPattern().height(), m_pattern->getPattern().width() * 4);
 		cairo_pattern_t *m_pat = cairo_pattern_create_for_surface(image2);
 		cairo_pattern_set_extend(m_pat, CAIRO_EXTEND_REPEAT);
 		cairo_pattern_set_filter(m_pat, CAIRO_FILTER_GOOD);
@@ -1254,7 +1254,7 @@ void ScPainter::strokePathHelper()
 		qmatrix.rotate(m_patternTrans.rotation);
 		qmatrix.shear(-m_patternTrans.skewX, m_patternTrans.skewY);
 		qmatrix.scale(m_patternTrans.scaleX, m_patternTrans.scaleY);
-		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
+		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern().width()), m_pattern->height / static_cast<double>(m_pattern->getPattern().height()));
 		if (m_patternMirrorX)
 			qmatrix.scale(-1, 1);
 		if (m_patternMirrorY)
