@@ -25,10 +25,8 @@ TextShaper::TextShaper(ITextContext* context, ITextSource &story, int firstChar,
 { }
 
 TextShaper::TextShaper(ITextSource &story, int firstChar)
-	: m_context(nullptr),
-	m_story(story),
-	m_firstChar(firstChar),
-	m_singlePar(false)
+	: m_story(story),
+	  m_firstChar(firstChar)
 {
 	m_text.reserve(m_story.length() - m_firstChar + 1);
 	for (int i = m_firstChar; i < m_story.length(); ++i)
@@ -42,14 +40,14 @@ TextShaper::TextShaper(ITextSource &story, int firstChar)
 	}
 }
 
-QList<TextShaper::TextRun> TextShaper::itemizeBiDi() const
+QList<TextShaper::TextRun> TextShaper::itemizeBiDi(int fromPos) const
 {
 	QList<TextRun> textRuns;
 	UBiDi *obj = ubidi_open();
 	UErrorCode err = U_ZERO_ERROR;
 
 	UBiDiLevel parLevel = UBIDI_LTR;
-	ParagraphStyle style = m_story.paragraphStyle(m_firstChar);
+	const ParagraphStyle& style = m_story.paragraphStyle(fromPos);
 	if (style.direction() == ParagraphStyle::RTL)
 		parLevel = UBIDI_RTL;
 
@@ -274,7 +272,7 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 
 	buildText(fromPos, toPos, smallCaps);
 
-	QList<TextRun> bidiRuns = itemizeBiDi();
+	QList<TextRun> bidiRuns = itemizeBiDi(fromPos);
 	QList<TextRun> scriptRuns = itemizeScripts(bidiRuns);
 	QList<TextRun> textRuns = itemizeStyles(scriptRuns);
 
@@ -283,7 +281,8 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 	// FIXME-HOST: add some fallback code if the iterator failed
 	if (lineIt)
 	{
-		lineIt->setText((const UChar*) m_text.utf16());
+		icu::UnicodeString unicodeStr(true, (const UChar*) m_text.utf16(), m_text.length());
+		lineIt->setText(unicodeStr);
 		for (int32_t pos = lineIt->first(); pos != BreakIterator::DONE; pos = lineIt->next())
 			lineBreaks.append(pos);
 	}
@@ -308,7 +307,8 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 			if (charIt)
 			{
 				const QString text = m_text.mid(run.start, run.len);
-				charIt->setText((const UChar*) text.utf16());
+				icu::UnicodeString unicodeStr((const UChar*) text.utf16());
+				charIt->setText(unicodeStr);
 				int32_t pos = charIt->first();
 				while (pos != BreakIterator::DONE && pos < text.length())
 				{
@@ -340,7 +340,10 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 		hb_font_set_scale(hbFont, style.fontSize(), style.fontSize());
 		FT_Face ftFace = hb_ft_font_get_face(hbFont);
 		if (ftFace)
+		{
 			FT_Set_Char_Size(ftFace, style.fontSize(), 0, 72, 0);
+			hb_ft_font_changed(hbFont);
+		}
 
 		hb_direction_t hbDirection = (textRun.dir == UBIDI_LTR) ? HB_DIRECTION_LTR : HB_DIRECTION_RTL;
 		hb_script_t hbScript = hb_icu_script_to_script(textRun.script);
