@@ -188,6 +188,7 @@ ScAnnot::ScAnnot(QWidget* parent, PageItem *it, ScribusDoc* doc, ScribusView* vi
 	MaxChars->setEnabled(setter);
 	NoScroll->setChecked(m_annotation.Flag() & Annotation::Flag_DoNotScroll);
 	NoSpell->setChecked(m_annotation.Flag() & Annotation::Flag_DoNotSpellCheck);
+	AutoTextSize->setChecked(m_annotation.Flag() & Annotation::Flag_AutoTextSize);
 
 	ChkStil->setCurrentIndex(m_annotation.ChkStil());
 	isChkd->setChecked(m_annotation.IsChk());
@@ -853,8 +854,9 @@ void ScAnnot::DecodeNum()
 	}
 	if (m_annotation.Format() == 3)
 	{
-		setCurrentComboItem(Format0c, pfol[0].remove("\""));
-		setDateSample(pfol[0]);
+		pfo.remove("\"");
+		setCurrentComboItem(Format0c, pfo);
+		setDateSample(pfo);
 	}
 	if (m_annotation.Format() == 4)
 	{
@@ -1140,6 +1142,8 @@ void ScAnnot::SetValues()
 			annotation.addToFlag(Annotation::Flag_DoNotSpellCheck);
 		if (NoScroll->isChecked())
 			annotation.addToFlag(Annotation::Flag_DoNotScroll);
+		if (AutoTextSize->isChecked())
+			annotation.addToFlag(Annotation::Flag_AutoTextSize);
 	}
 	if ((annotation.Type() == Annotation::Textfield) || (annotation.Type() == Annotation::Combobox))
 	{
@@ -1422,6 +1426,7 @@ void ScAnnot::SetAnnotationType(int it)
 	CanEdit->setChecked(annotation.Flag() & Annotation::Flag_Edit);
 	NoSpell->setChecked(annotation.Flag() & Annotation::Flag_DoNotSpellCheck);
 	NoScroll->setChecked(annotation.Flag() & Annotation::Flag_DoNotScroll);
+	AutoTextSize->setChecked(annotation.Flag() & Annotation::Flag_AutoTextSize);
 	ChkStil->setCurrentIndex(annotation.ChkStil());
 	isChkd->setChecked(annotation.IsChk());
 	setter = annotation.MaxChar() != -1;
