@@ -10,7 +10,8 @@ for which a new license (GPL+exception) is in place.
 #include <QWidget>
 #include "scribusapi.h"
 #include "ui_arcwidgetbase.h"
-struct toolPrefs;
+
+struct ItemToolPrefs;
 
 class SCRIBUS_API ArcWidget : public QWidget, Ui::ArcWidgetBase
 {
@@ -19,8 +20,9 @@ class SCRIBUS_API ArcWidget : public QWidget, Ui::ArcWidgetBase
 	public:
 		ArcWidget(QWidget* parent);
 		~ArcWidget() {};
-		void restoreDefaults(struct ItemToolPrefs *prefsData);
-		void saveGuiToPrefs(struct ItemToolPrefs *prefsData);
+
+		void restoreDefaults(const ItemToolPrefs *prefsData);
+		void saveGuiToPrefs(ItemToolPrefs *prefsData);
 
 	protected slots:
 		void updatePreview();
