@@ -12,8 +12,9 @@ for which a new license (GPL+exception) is in place.
 
 #include "autoformbuttongroup.h"
 #include "fpointarray.h"
-#include "scpainter.h"
 #include "iconmanager.h"
+#include "scpainter.h"
+#include "scribusapp.h"
 
 AutoformButtonGroup::AutoformButtonGroup( QWidget* parent ) : QMenu( parent )
 {
@@ -73,6 +74,8 @@ AutoformButtonGroup::AutoformButtonGroup( QWidget* parent ) : QMenu( parent )
 	addMenu(menu3);
 	addMenu(menu4);
 	addMenu(menu5);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 	connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(selForm(int)));
 }
 
@@ -727,10 +730,8 @@ QPixmap AutoformButtonGroup::getIconPixmap(int nr, int pixmapSize)
 	QImage Ico(32, 32, QImage::Format_ARGB32_Premultiplied);
 	Ico.fill(0);
 	int count = 0;
-	qreal* AutoShapes;
 	FPointArray Path;
-	Path.resize(0);
-	AutoShapes = getShapeData(nr, &count);
+	qreal* AutoShapes = getShapeData(nr, &count);
 	for (int i = 0; i < count - 3; i += 4)
 	{
 		if (AutoShapes[i] < 0)
@@ -769,6 +770,21 @@ void AutoformButtonGroup::changeEvent(QEvent *e)
 		QMenu::changeEvent(e);
 }
 
+void AutoformButtonGroup::iconSetChange()
+{
+	for (int i = 0; i <= 44; ++i)
+	{
+		QObject* mappedObject = signalMapper->mapping(i);
+		if (!mappedObject)
+			continue;
+
+		QAction* action = qobject_cast<QAction*>(mappedObject);
+		if (!action)
+			continue;
+		action->setIcon(QIcon(getIconPixmap(i, 16)));
+	}
+}
+
 void AutoformButtonGroup::languageChange()
 {
 	menu1->setTitle( tr("Default Shapes"));
