@@ -32,10 +32,9 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 // readable constants for QTreeWidgetItem column ids
-#define COLUMN_ITEM 0
-#define COLUMN_PROBLEM 1
-#define COLUMN_LAYER 2
-// #define COLUMN_INFO 3
+constexpr int COLUMN_ITEM = 0;
+constexpr int COLUMN_PROBLEM = 1;
+constexpr int COLUMN_LAYER = 2;
 
 CheckDocument::CheckDocument( QWidget* parent, bool modal )
 	: ScrPaletteBase( parent, "checkDocument", modal )
@@ -114,7 +113,7 @@ void CheckDocument::languageChange()
 	setWindowTitle( tr( "Preflight Verifier" ) );
 	QStringList headerLabels;
 	headerLabels << tr("Items") << tr("Problems")
-				 << tr("Layer");// << tr("Information");
+				 << tr("Layer");
 	reportDisplay->setHeaderLabels(headerLabels);
 	reportDisplay->setColumnCount(headerLabels.count());
 
@@ -191,9 +190,8 @@ void CheckDocument::setDoc(ScribusDoc *doc)
 {
 	m_Doc = doc;
 	clearErrorList();
-	CheckerPrefsList::Iterator it;
-	CheckerPrefsList::Iterator itend=doc->checkerProfiles().end();
-	for (it = doc->checkerProfiles().begin(); it != itend ; ++it)
+	CheckerPrefsList::Iterator itend = doc->checkerProfiles().end();
+	for (auto it = doc->checkerProfiles().begin(); it != itend ; ++it)
 		curCheckProfile->addItem(it.key());
 	setCurrentComboItem(curCheckProfile, doc->curCheckProfile());
 }
@@ -254,15 +252,15 @@ void CheckDocument::slotSelect(QTreeWidgetItem* ite)
 
 void CheckDocument::doReScan()
 {
-	showPagesWithoutErrors=PrefsManager::instance().appPrefs.verifierPrefs.showPagesWithoutErrors;
-	showNonPrintingLayerErrors=PrefsManager::instance().appPrefs.verifierPrefs.showNonPrintingLayerErrors;
+	showPagesWithoutErrors = PrefsManager::instance().appPrefs.verifierPrefs.showPagesWithoutErrors;
+	showNonPrintingLayerErrors = PrefsManager::instance().appPrefs.verifierPrefs.showNonPrintingLayerErrors;
 	newScan(curCheckProfile->currentText());
 }
 
 void CheckDocument::newScan(const QString& name)
 {
 	clearErrorList();
-	if (m_Doc==nullptr)
+	if (m_Doc == nullptr)
 		return;
 	m_Doc->setCurCheckProfile(name);
 	DocumentChecker::checkDocument(m_Doc);
@@ -396,7 +394,7 @@ void CheckDocument::buildItem(QTreeWidgetItem * item,
 			break;
 		default:
 			break;
-	};
+	}
 	// additional information
 	const ScLayer* layer = m_Doc->Layers.layerByID(pageItem->m_layerID);
 	if (layer)
@@ -408,21 +406,19 @@ void CheckDocument::buildItem(QTreeWidgetItem * item,
 
 void CheckDocument::buildErrorList(ScribusDoc *doc)
 {
-// 	bool resultError = false;
 	m_Doc = doc;
 	disconnect(curCheckProfile, SIGNAL(activated(const QString&)), this, SLOT(newScan(const QString&)));
 	curCheckProfile->clear();
 	clearErrorList();
 
-	if (m_Doc==nullptr)
+	if (m_Doc == nullptr)
 		return;
 
 	minResDPI = qRound(doc->checkerProfiles()[doc->curCheckProfile()].minResolution);
 	maxResDPI = qRound(doc->checkerProfiles()[doc->curCheckProfile()].maxResolution);
 	
-	CheckerPrefsList::Iterator it;
-	CheckerPrefsList::Iterator itend=doc->checkerProfiles().end();
-	for (it = doc->checkerProfiles().begin(); it != itend ; ++it)
+	CheckerPrefsList::Iterator itend = doc->checkerProfiles().end();
+	for (auto it = doc->checkerProfiles().begin(); it != itend; ++it)
 		curCheckProfile->addItem(it.key());
 	setCurrentComboItem(curCheckProfile, doc->curCheckProfile());
 	if (!doc->hasPreflightErrors()
@@ -441,7 +437,6 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 		bool layoutGraveError = false;
 		itemError = false;
 
-
 		// MARKS ***********************************************
 		if (doc->notesChanged())
 		{
@@ -455,17 +450,14 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 		QTreeWidgetItem * layerItem = new QTreeWidgetItem(reportDisplay);
 		layerItem->setText(COLUMN_ITEM, tr("Layers"));
 
-		if (doc->docLayerErrors.count() != 0)
+		if (!doc->docLayerErrors.isEmpty())
 		{
-			QMap<int, errorCodes>::Iterator docLayerErrorsIt;
-			errorCodes::Iterator layerErrorsIt;
-
-			for (docLayerErrorsIt = doc->docLayerErrors.begin();
+			for (auto docLayerErrorsIt = doc->docLayerErrors.begin();
 				 docLayerErrorsIt != doc->docLayerErrors.end();
 				 ++docLayerErrorsIt)
 			{
 				QTreeWidgetItem * layer = new QTreeWidgetItem(layerItem);
-				for (layerErrorsIt = docLayerErrorsIt.value().begin();
+				for (auto layerErrorsIt = docLayerErrorsIt.value().begin();
 					 layerErrorsIt != docLayerErrorsIt.value().end(); ++layerErrorsIt)
 				{
 					QTreeWidgetItem * errorText = new QTreeWidgetItem( layer, 0 );
@@ -513,73 +505,70 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 		{
 			hasError = false;
 			pageGraveError = false;
-			QTreeWidgetItem * page=nullptr;
+			QTreeWidgetItem* page = nullptr;
+			ScPage* masterPage = doc->MasterPages.at(mPage);
 			if (showPagesWithoutErrors)
 			{
-				page = new QTreeWidgetItem( masterPageRootItem);
-				masterPageMap.insert(page, doc->MasterPages.at(mPage));
+				page = new QTreeWidgetItem(masterPageRootItem);
+				masterPageMap.insert(page, masterPage);
 			}
 
-			QMap<PageItem*, errorCodes>::Iterator masterItemErrorsIt;
-			for (masterItemErrorsIt = doc->masterItemErrors.begin();
+			for (auto masterItemErrorsIt = doc->masterItemErrors.begin();
 				 masterItemErrorsIt != doc->masterItemErrors.end();
 				 ++masterItemErrorsIt)
 			{
-				if (((masterItemErrorsIt.key()->OwnPage == mPage)
-					|| (masterItemErrorsIt.key()->OnMasterPage == doc->MasterPages.at(mPage)->pageName()))
-					&&
-					((showNonPrintingLayerErrors) ||
-					(!showNonPrintingLayerErrors && doc->layerPrintable(masterItemErrorsIt.key()->m_layerID)))
-					)
+				PageItem* masterItem = masterItemErrorsIt.key();
+				if ((masterItem->OwnPage != mPage) && (masterItem->OnMasterPage != masterPage->pageName()))
+					continue;
+				if (!showNonPrintingLayerErrors && !doc->layerPrintable(masterItem->m_layerID))
+					continue;
+
+				if (!showPagesWithoutErrors && page == nullptr)
 				{
-					if (!showPagesWithoutErrors && page==nullptr)
+					page = new QTreeWidgetItem(masterPageRootItem);
+					masterPageMap.insert(page, doc->MasterPages.at(mPage));
+				}
+				hasError = true;
+				QTreeWidgetItem* object = new QTreeWidgetItem(page);
+				masterPageItemMap.insert(object, masterItem);
+				object->setText(COLUMN_ITEM, masterItem->itemName());
+				if (masterItemErrorsIt.value().count() == 1)
+				{
+					auto it3 = masterItemErrorsIt.value().begin();
+					buildItem(object, it3.key(), masterItem);
+					posMap.insert(object, it3.value());
+				}
+				else
+				{
+					for (auto it3 = masterItemErrorsIt.value().begin(); it3 != masterItemErrorsIt.value().end(); ++it3)
 					{
-						page = new QTreeWidgetItem( masterPageRootItem);
-						masterPageMap.insert(page, doc->MasterPages.at(mPage));
-					}
-					hasError = true;
-					QTreeWidgetItem * object = new QTreeWidgetItem( page);
-					masterPageItemMap.insert(object, masterItemErrorsIt.key());
-					object->setText(COLUMN_ITEM, masterItemErrorsIt.key()->itemName());
-					errorCodes::Iterator it3;
-					if (masterItemErrorsIt.value().count() == 1)
-					{
-						it3 = masterItemErrorsIt.value().begin();
-						buildItem(object, it3.key(), masterItemErrorsIt.key());
+						QTreeWidgetItem* errorText = new QTreeWidgetItem(object, 0);
+						buildItem(errorText, it3.key(), masterItem);
+						masterPageItemMap.insert(errorText, masterItem);
 						posMap.insert(object, it3.value());
 					}
-					else
-					{
-						for (it3 = masterItemErrorsIt.value().begin(); it3 != masterItemErrorsIt.value().end(); ++it3)
-						{
-							QTreeWidgetItem * errorText = new QTreeWidgetItem( object, 0 );
-							buildItem(errorText, it3.key(), masterItemErrorsIt.key());
-							masterPageItemMap.insert(errorText, masterItemErrorsIt.key());
-							posMap.insert(object, it3.value());
-						}
-						object->setExpanded( true );
-					}
-					if (itemError)
-						object->setIcon(COLUMN_ITEM, graveError );
-					else
-						object->setIcon(COLUMN_ITEM, onlyWarning );
+					object->setExpanded(true);
 				}
+				if (itemError)
+					object->setIcon(COLUMN_ITEM, graveError);
+				else
+					object->setIcon(COLUMN_ITEM, onlyWarning);
 			}
 			if (hasError)
 			{
 				++mpErrorCount;
 				if (pageGraveError)
-					page->setIcon(COLUMN_ITEM, graveError );
+					page->setIcon(COLUMN_ITEM, graveError);
 				else
-					page->setIcon(COLUMN_ITEM, onlyWarning );
-				page->setExpanded( true );
+					page->setIcon(COLUMN_ITEM, onlyWarning);
+				page->setExpanded(true);
 			}
 			else
 			{
-				if (showPagesWithoutErrors && page!=nullptr)
-					page->setIcon(COLUMN_ITEM, noErrors );
+				if (showPagesWithoutErrors && page != nullptr)
+					page->setIcon(COLUMN_ITEM, noErrors);
 			}
-			if (page!=nullptr)
+			if (page != nullptr)
 				page->setText(COLUMN_ITEM, doc->MasterPages.at(mPage)->pageName());
 		}
 		masterPageRootItem->setExpanded(true);
@@ -593,105 +582,100 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 			QString tmp;
 			hasError = false;
 			pageGraveError = false;
-			QTreeWidgetItem * page=nullptr;
+			QTreeWidgetItem* page = nullptr;
 			if (showPagesWithoutErrors)
 			{
 				page = new QTreeWidgetItem( reportDisplay);
 				pageMap.insert(page, doc->DocPages.at(aPage));
 			}
 
-			QMap<int, errorCodes>::Iterator pageErrorsIt;
-			for (pageErrorsIt = doc->pageErrors.begin();
+			for (auto pageErrorsIt = doc->pageErrors.begin();
 				 pageErrorsIt != doc->pageErrors.end();
 				 ++pageErrorsIt)
 			{
-				if (pageErrorsIt.key() == aPage)
+				if (pageErrorsIt.key() != aPage)
+					continue;
+				if (page == nullptr)
 				{
-					if (page==nullptr)
-					{
-						page = new QTreeWidgetItem( reportDisplay);
-						pageMap.insert(page, doc->DocPages.at(aPage));
-					}
-					QTreeWidgetItem * errorText = new QTreeWidgetItem(page);
-					errorText->setText(COLUMN_PROBLEM, warnMap[PV_APPLIED_MASTER_DIFF_SIDE].first);
-					errorText->setToolTip(COLUMN_PROBLEM, warnMap[PV_APPLIED_MASTER_DIFF_SIDE].second);
-					errorText->setIcon(COLUMN_ITEM, onlyWarning );
-					pageMap.insert(errorText, doc->DocPages.at(aPage));
-					hasError=true;
-					page->setExpanded( true );
-					++pageErrorCount;
+					page = new QTreeWidgetItem(reportDisplay);
+					pageMap.insert(page, doc->DocPages.at(aPage));
 				}
+				QTreeWidgetItem * errorText = new QTreeWidgetItem(page);
+				errorText->setText(COLUMN_PROBLEM, warnMap[PV_APPLIED_MASTER_DIFF_SIDE].first);
+				errorText->setToolTip(COLUMN_PROBLEM, warnMap[PV_APPLIED_MASTER_DIFF_SIDE].second);
+				errorText->setIcon(COLUMN_ITEM, onlyWarning );
+				pageMap.insert(errorText, doc->DocPages.at(aPage));
+				hasError = true;
+				page->setExpanded( true );
+				++pageErrorCount;
 			}
 
-			QMap<PageItem*, errorCodes>::Iterator docItemErrorsIt;
-			for (docItemErrorsIt = doc->docItemErrors.begin();
+			for (auto docItemErrorsIt = doc->docItemErrors.begin();
 				 docItemErrorsIt != doc->docItemErrors.end();
 				 ++docItemErrorsIt)
 			{
-				if (docItemErrorsIt.key()->OwnPage == aPage &&
-					((showNonPrintingLayerErrors) ||
-					(!showNonPrintingLayerErrors && doc->layerPrintable(docItemErrorsIt.key()->m_layerID)))
-					)
+				PageItem* pageItem = docItemErrorsIt.key();
+				if (pageItem->OwnPage != aPage)
+					continue;
+				if (!showNonPrintingLayerErrors && !doc->layerPrintable(pageItem->m_layerID))
+					continue;
+
+				if (!showPagesWithoutErrors && page == nullptr)
 				{
-					if (!showPagesWithoutErrors && page==nullptr)
+					page = new QTreeWidgetItem(reportDisplay);
+					pageMap.insert(page, doc->DocPages.at(aPage));
+				}
+				hasError = true;
+				itemError = false;
+				QTreeWidgetItem* object = new QTreeWidgetItem(page);
+				object->setText(COLUMN_ITEM, pageItem->itemName());
+				itemMap.insert(object, pageItem);
+				if (docItemErrorsIt.value().count() == 1)
+				{
+					auto it3 = docItemErrorsIt.value().begin();
+					buildItem(object, it3.key(), pageItem);
+					posMap.insert(object, it3.value());
+					++pageErrorCount;
+				}
+				else
+				{
+					for (auto it3 = docItemErrorsIt.value().begin(); it3 != docItemErrorsIt.value().end(); ++it3)
 					{
-						page = new QTreeWidgetItem( reportDisplay);
-						pageMap.insert(page, doc->DocPages.at(aPage));
-					}
-					hasError = true;
-					itemError = false;
-					QTreeWidgetItem * object = new QTreeWidgetItem(page);
-					object->setText(COLUMN_ITEM, docItemErrorsIt.key()->itemName());
-					itemMap.insert(object, docItemErrorsIt.key());
-					errorCodes::Iterator it3;
-					if (docItemErrorsIt.value().count() == 1)
-					{
-						it3 = docItemErrorsIt.value().begin();
-						buildItem(object, it3.key(), docItemErrorsIt.key());
+						QTreeWidgetItem* errorText = new QTreeWidgetItem(object);
+						buildItem(errorText, it3.key(), pageItem);
+						itemMap.insert(errorText, pageItem);
 						posMap.insert(object, it3.value());
 						++pageErrorCount;
 					}
-					else
-					{
-						for (it3 = docItemErrorsIt.value().begin(); it3 != docItemErrorsIt.value().end(); ++it3)
-						{
-							QTreeWidgetItem * errorText = new QTreeWidgetItem( object);
-							buildItem(errorText, it3.key(), docItemErrorsIt.key());
-							itemMap.insert(errorText, docItemErrorsIt.key());
-							posMap.insert(object, it3.value());
-							++pageErrorCount;
-						}
-						object->setExpanded( true );
-					}
-					if (itemError)
-						object->setIcon(COLUMN_ITEM, graveError );
-					else
-						object->setIcon(COLUMN_ITEM, onlyWarning );
+					object->setExpanded(true);
 				}
+				if (itemError)
+					object->setIcon(COLUMN_ITEM, graveError);
+				else
+					object->setIcon(COLUMN_ITEM, onlyWarning);
 			}
 			if (hasError)
 			{
 				if (pageGraveError)
-					page->setIcon(COLUMN_ITEM, graveError );
+					page->setIcon(COLUMN_ITEM, graveError);
 				else
-					page->setIcon(COLUMN_ITEM, onlyWarning );
-				page->setExpanded( true );
-				page->setText(COLUMN_PROBLEM, tr( "Issues: %1" ).arg(pageErrorCount) );
+					page->setIcon(COLUMN_ITEM, onlyWarning);
+				page->setExpanded(true);
+				page->setText(COLUMN_PROBLEM, tr("Issues: %1").arg(pageErrorCount));
 			}
 			else
 			{
-				if (showPagesWithoutErrors && page!=nullptr)
-					page->setIcon( 0, noErrors );
+				if (showPagesWithoutErrors && page != nullptr)
+					page->setIcon(0, noErrors);
 			}
-			if (page!=nullptr)
-				page->setText(COLUMN_ITEM, tr("Page ")+tmp.setNum(aPage+1));
+			if (page != nullptr)
+				page->setText(COLUMN_ITEM, tr("Page ") + tmp.setNum(aPage + 1));
 		}
 		// END of PAGES
 
 		// FREE ITEMS **************************************************
-		QMap<PageItem*, errorCodes>::Iterator freeItemsErrorsIt;
 		bool hasfreeItems = false;
-		for (freeItemsErrorsIt = doc->docItemErrors.begin(); freeItemsErrorsIt != doc->docItemErrors.end(); ++freeItemsErrorsIt)
+		for (auto freeItemsErrorsIt = doc->docItemErrors.begin(); freeItemsErrorsIt != doc->docItemErrors.end(); ++freeItemsErrorsIt)
 		{
 			if (doc->OnPage(freeItemsErrorsIt.key()) == -1)
 			{
@@ -704,7 +688,7 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 			bool hasError = false;
 			bool pageGraveError = false;
 			QTreeWidgetItem * freeItem = new QTreeWidgetItem( reportDisplay);
-			for (freeItemsErrorsIt = doc->docItemErrors.begin(); freeItemsErrorsIt != doc->docItemErrors.end(); ++freeItemsErrorsIt)
+			for (auto freeItemsErrorsIt = doc->docItemErrors.begin(); freeItemsErrorsIt != doc->docItemErrors.end(); ++freeItemsErrorsIt)
 			{
 				if (doc->OnPage(freeItemsErrorsIt.key()) == -1)
 				{
@@ -712,23 +696,22 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 					QTreeWidgetItem * object = new QTreeWidgetItem(freeItem);
 					object->setText(0, freeItemsErrorsIt.key()->itemName());
 					itemMap.insert(object, freeItemsErrorsIt.key());
-					errorCodes::Iterator it3;
 					if (freeItemsErrorsIt.value().count() == 1)
 					{
-						it3 = freeItemsErrorsIt.value().begin();
+						auto it3 = freeItemsErrorsIt.value().begin();
 						buildItem(object, it3.key(), freeItemsErrorsIt.key());
 						posMap.insert(object, it3.value());
 					}
 					else
 					{
-						for (it3 = freeItemsErrorsIt.value().begin(); it3 != freeItemsErrorsIt.value().end(); ++it3)
+						for (auto it3 = freeItemsErrorsIt.value().begin(); it3 != freeItemsErrorsIt.value().end(); ++it3)
 						{
-							QTreeWidgetItem * errorText = new QTreeWidgetItem( object);
+							QTreeWidgetItem* errorText = new QTreeWidgetItem(object);
 							buildItem(errorText, it3.key(), freeItemsErrorsIt.key());
 							itemMap.insert(errorText, freeItemsErrorsIt.key());
 							posMap.insert(object, it3.value());
 						}
-						object->setExpanded( true );
+						object->setExpanded(true);
 					}
 					if (pageGraveError)
 						object->setIcon(COLUMN_ITEM, graveError );
@@ -766,7 +749,7 @@ void CheckDocument::setIgnoreEnabled(bool state)
 	ignoreErrors->setVisible(state);
 }
 
-bool CheckDocument::isIgnoreEnabled()
+bool CheckDocument::isIgnoreEnabled() const
 {
 	return !noButton;
 }
