@@ -15,19 +15,17 @@ class CollectForOutput_UI : public CollectForOutput
 {
 	Q_OBJECT
 	public:
-	CollectForOutput_UI(QWidget *parent, ScribusDoc* doc, const QString& outputDirectory=QString(), bool withFonts=false, bool withProfiles=false, bool compressDoc=false);
-	virtual QString collect(QString &newFileName);
-
-	signals:
+		CollectForOutput_UI(QWidget* parent, ScribusDoc* doc, const QString& outputDirectory = QString(), bool withFonts = false, bool withProfiles = false, bool compressDoc = false);
+		virtual QString collect(QString &newFileName);
 
 	protected slots:
-	void collectedFonts(int);
-	void collectedItems(int);
-	void collectedPatterns(int);
-	void collectedProfiles(int);
+		void collectedFonts(int);
+		void collectedItems(int);
+		void collectedPatterns(int);
+		void collectedProfiles(int);
 
 	protected:
-	MultiProgressDialog* progressDialog;
+		MultiProgressDialog* progressDialog { nullptr };
 };
 
 #endif // COLLECTFOROUTPUT_UI_H
