@@ -61,8 +61,6 @@ for which a new license (GPL+exception) is in place.
 #include "util_color.h"
 #include "util_formats.h"
 
-extern QString DocDir;
-
 ImIconProvider::ImIconProvider()
 {
 	QString tmp[] = {"eps", "epsi", "gif", "png", "jpg", "jpeg", "xpm", "tif", "tiff", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm", "psd", "pat"};
@@ -235,8 +233,7 @@ void FDialogPreview::genPreview(const QString& name)
 			f = QString::fromUtf8(cf.data());
 		else
 			f = cf.data();
-		ScPreview *pre = new ScPreview();
-		QImage im = pre->createPreview(f);
+		QImage im = ScPreview::create(f);
 		im = im.scaled(w - 5, h - 21, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
 		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
@@ -250,7 +247,6 @@ void FDialogPreview::genPreview(const QString& name)
 		p.end();
 		setPixmap(pm);
 		repaint();
-		delete pre;
 	}
 	else
 	{
@@ -481,6 +477,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	fileDialog->forceDoubleClickActivation(m_previewIsShown);
 	fileDialog->setOption(QFileDialog::HideNameFilterDetails, true);
 	m_extZip = "gz";
+
 	connect(okButton, SIGNAL(clicked()), this, SLOT(okClicked()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 	connect(showPreview, SIGNAL(clicked()), this, SLOT(togglePreview()));
@@ -488,7 +485,6 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	connect(fileDialog, SIGNAL(filesSelected(const QStringList &)), this, SLOT(accept()));
 	connect(fileDialog, SIGNAL(accepted()), this, SLOT(accept()));
 	connect(fileDialog, SIGNAL(rejected()), this, SLOT(reject()));
-	resize(minimumSizeHint());
 }
 
 void CustomFDialog::closeEvent(QCloseEvent *closeEvent)
@@ -543,7 +539,7 @@ void CustomFDialog::fileClicked(const QString &path)
 
 void CustomFDialog::okClicked()
 {
-	QString selFile=selectedFile();
+	QString selFile = selectedFile();
 	if (selFile.isEmpty())
 		return;
 	QFileInfo fi(selFile);
