@@ -44,15 +44,15 @@ for which a new license (GPL+exception) is in place.
 
 #include "iconmanager.h"
 
-#ifdef Q_OS_MAC
-#define topline 1
+#ifdef Q_OS_MACOS
+constexpr int topline = 1;
 #else
-#define topline 3
+constexpr int topline = 3;
 #endif
-#define bottomline 15
-#define rulerheight (bottomline - topline)
-#define midline (topline + rulerheight/2)
-#define tabline 7
+constexpr int bottomline = 15;
+constexpr int rulerheight = (bottomline - topline);
+constexpr int midline = (topline + rulerheight / 2);
+constexpr int tabline = 7;
 
 Hruler::Hruler(ScribusView *pa, ScribusDoc *doc) : QWidget(pa),
 	m_doc(doc),
@@ -102,7 +102,7 @@ void Hruler::shiftRel(double dist)
 }
 
 
-int Hruler::findRulerHandle(QPoint mp, double grabRadius)
+int Hruler::findRulerHandle(QPoint mp, int grabRadius)
 {
 	int mx = mp.x();
 	QRect fpo;
@@ -117,7 +117,7 @@ int Hruler::findRulerHandle(QPoint mp, double grabRadius)
 	if (pos + 1 < (mx + grabRadius) && pos + 1 > (mx - grabRadius))
 		result = rc_rightFrameDist;
 	
-	double colWidth = (textWidth() - m_colGap * (m_cols - 1)) / m_cols;
+	double colWidth = (textWidth() - m_colGap * (m_cols - 1.0)) / m_cols;
 	
 	m_currCol = 0;
 	for (int currCol = 0; currCol < m_cols; ++currCol)
@@ -136,19 +136,19 @@ int Hruler::findRulerHandle(QPoint mp, double grabRadius)
 		return result;
 	}
 	
-	pos = textPosToLocal(m_firstIndent + m_leftMargin + (colWidth + m_colGap) * (m_currCol - 1));
-	fpo = QRect(pos - 1, topline, grabRadius + 1, rulerheight/2);
+	pos = textPosToLocal(m_firstIndent + m_leftMargin + (colWidth + m_colGap) * (m_currCol - 1.0));
+	fpo = QRect(pos - 1, topline, grabRadius + 1, rulerheight / 2);
 	if (fpo.contains(mp))
 	{
 		return rc_indentFirst;
 	}
-	pos = textPosToLocal(m_leftMargin + (colWidth + m_colGap) * (m_currCol - 1));
-	fpo = QRect(pos - 1, midline, grabRadius + 1, rulerheight/2);
+	pos = textPosToLocal(m_leftMargin + (colWidth + m_colGap) * (m_currCol - 1.0));
+	fpo = QRect(pos - 1, midline, grabRadius + 1, rulerheight / 2);
 	if (fpo.contains(mp))
 	{
 		return rc_leftMargin;
 	}
-	pos = textPosToLocal(m_rightMargin + (colWidth + m_colGap) * (m_currCol- 1));
+	pos = textPosToLocal(m_rightMargin + (colWidth + m_colGap) * (m_currCol - 1.0));
 	fpo = QRect(pos - grabRadius, midline, grabRadius, rulerheight / 2);
 	if (fpo.contains(mp))
 	{
@@ -158,7 +158,7 @@ int Hruler::findRulerHandle(QPoint mp, double grabRadius)
 	{
 		for (int yg = 0; yg < m_tabValues.count(); yg++)
 		{
-			pos = textPosToLocal(m_tabValues[yg].tabPosition + (colWidth + m_colGap) * (m_currCol - 1));
+			pos = textPosToLocal(m_tabValues[yg].tabPosition + (colWidth + m_colGap) * (m_currCol - 1.0));
 			fpo = QRect(pos - grabRadius, tabline, 2 * grabRadius, rulerheight / 2 + 2);
 			if (fpo.contains(mp))
 			{
@@ -182,17 +182,20 @@ void Hruler::mousePressEvent(QMouseEvent *m)
 	{
 		m_rulerCode = findRulerHandle(m->pos(), m_doc->guidesPrefs().grabRadius);
 		
-		if ((m_rulerCode == rc_none) && (m_currCol != 0) && (m->button() == Qt::LeftButton))
+		double tabPos = localToTextPos(m->x());
+		bool isInTextRange = (tabPos >= 0) && (tabPos <= textWidth());
+		if (isInTextRange && (m_rulerCode == rc_none) && (m_currCol != 0) && (m->button() == Qt::LeftButton))
 		{
+			const QString& textTabFillChar = m_doc->itemToolPrefs().textTabFillChar;
 			ParagraphStyle::TabRecord tb;
-			tb.tabPosition = localToTextPos(m->x());
+			tb.tabPosition = tabPos;
 			tb.tabType = 0;
-			tb.tabFillChar = m_doc->itemToolPrefs().textTabFillChar[0];
+			tb.tabFillChar = !textTabFillChar.isEmpty() ? textTabFillChar[0] : QChar();
 			m_tabValues.prepend(tb);
 			m_currTab = 0;
 			m_rulerCode = rc_tab;
 			updateTabList();
-			qApp->setOverrideCursor(QCursor(Qt::SizeHorCursor));
+			QApplication::setOverrideCursor(QCursor(Qt::SizeHorCursor));
 			emit DocChanged(false);
 		}
 	}
@@ -200,7 +203,7 @@ void Hruler::mousePressEvent(QMouseEvent *m)
 	{
 		if (m_doc->guidesPrefs().guidesShown)
 		{
-			qApp->setOverrideCursor(QCursor(Qt::SplitVCursor));
+			QApplication::setOverrideCursor(QCursor(Qt::SplitVCursor));
 			m_view->startGesture(rulerGesture);
 			m_view->registerMousePress(m->globalPos());
 		}
@@ -293,19 +296,19 @@ void Hruler::mouseReleaseEvent(QMouseEvent *m)
 	else if (m_mousePressed && rulerGesture->isActive())
 		rulerGesture->mouseReleaseEvent(m);
 	m_mousePressed = false;
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 }
 
 void Hruler::enterEvent(QEvent* e)
 {
 	if (m_textEditMode)
-		qApp->changeOverrideCursor(IconManager::instance().loadCursor("tab.png", 3));
+		QApplication::changeOverrideCursor(IconManager::instance().loadCursor("tab.png", 3));
 }
 
 void Hruler::leaveEvent(QEvent *m)
 {
 	emit MarkerMoved(0, -1);
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 	m_view->m_canvasMode->setModeCursor();
 }
 
@@ -315,24 +318,24 @@ void Hruler::mouseMoveEvent(QMouseEvent *m)
 		return;
 	if (m_textEditMode)
 	{
-		double colWidth = (textWidth() - m_colGap * (m_cols - 1)) / m_cols;
-		int ColEnd, ColStart;
+		int colEnd, colStart;
+		double colWidth = (textWidth() - m_colGap * (m_cols - 1.0)) / m_cols;
 		double oldInd;
 		if (m_rulerCode == rc_leftFrameDist || m_rulerCode == rc_rightFrameDist)
 		{
-			ColStart = 0; //textPosToLocal(0);
-			ColEnd   = width(); //textPosToLocal(textWidth());
+			colStart = 0; //textPosToLocal(0);
+			colEnd   = width(); //textPosToLocal(textWidth());
 		}
 		else
 		{
-			ColStart = textPosToLocal((colWidth + m_colGap) * (m_currCol- 1));
-			ColEnd   = textPosToLocal((colWidth + m_colGap) * (m_currCol- 1) + colWidth);
+			colStart = textPosToLocal((colWidth + m_colGap) * (m_currCol - 1.0));
+			colEnd   = textPosToLocal((colWidth + m_colGap) * (m_currCol - 1.0) + colWidth);
 		}
-		if ((m_mousePressed) && (m->y() < height()) && (m->y() > 0) && (m->x() > ColStart - m_doc->guidesPrefs().grabRadius) && (m->x() < ColEnd + m_doc->guidesPrefs().grabRadius))
+		if (m_mousePressed && (m->y() < height()) && (m->y() > 0) && (m->x() > colStart - m_doc->guidesPrefs().grabRadius) && (m->x() < colEnd + m_doc->guidesPrefs().grabRadius))
 		{
-			qApp->changeOverrideCursor(QCursor(Qt::SizeHorCursor));
-			double toplimit = textWidth() + m_distRight - (m_colGap * (m_cols - 1)) - 1;
-			double toplimit2 = textWidth() + m_distLeft - (m_colGap * (m_cols - 1)) - 1;
+			QApplication::changeOverrideCursor(QCursor(Qt::SizeHorCursor));
+			double toplimit = textWidth() + m_distRight - (m_colGap * (m_cols - 1.0)) - 1.0;
+			double toplimit2 = textWidth() + m_distLeft - (m_colGap * (m_cols - 1.0)) - 1.0;
 			switch (m_rulerCode)
 			{
 				case rc_leftFrameDist:
@@ -398,7 +401,7 @@ void Hruler::mouseMoveEvent(QMouseEvent *m)
 			m_mouseX = m->x();
 			return;
 		}
-		if ((!m_mousePressed) && (m->y() < height()) && (m->y() > 0) && (m->x() > ColStart - 2*m_doc->guidesPrefs().grabRadius) && (m->x() < ColEnd + 2*m_doc->guidesPrefs().grabRadius))
+		if ((!m_mousePressed) && (m->y() < height()) && (m->y() > 0) && (m->x() > colStart - 2 * m_doc->guidesPrefs().grabRadius) && (m->x() < colEnd + 2 * m_doc->guidesPrefs().grabRadius))
 		{
 			setCursor(IconManager::instance().loadCursor("tab.png", 3));
 			switch (findRulerHandle(m->pos(), m_doc->guidesPrefs().grabRadius))
@@ -421,13 +424,15 @@ void Hruler::mouseMoveEvent(QMouseEvent *m)
 				case rc_tab:
 					setCursor(QCursor(Qt::SizeHorCursor));
 					break;
+				default:
+					break;
 			}
 			draw(m->x());
 			double marker = localToTextPos(m->x());
 			emit MarkerMoved(textBase(), marker);
 			return;
 		}
-		if ((m_mousePressed) && (m_rulerCode == rc_tab) && ((m->y() > height()) || (m->y() < 0)))
+		if (m_mousePressed && (m_rulerCode == rc_tab) && ((m->y() > height()) || (m->y() < 0)))
 		{
 			setCursor(IconManager::instance().loadCursor("DelPoint.png", 1, 1));
 			return;
@@ -478,7 +483,7 @@ void Hruler::paintEvent(QPaintEvent *e)
 		}
 		for (int currCol = 0; currCol < m_cols; ++currCol)
 		{
-			double colWidth = (textWidth() - m_colGap * (m_cols - 1)) / m_cols;
+			double colWidth = (textWidth() - m_colGap * (m_cols - 1.0)) / m_cols;
 			double pos = (colWidth + m_colGap) * currCol;
 			double endPos = pos + colWidth;
 			drawTextMarks(pos, endPos, p);
@@ -509,61 +514,60 @@ void Hruler::paintEvent(QPaintEvent *e)
 			cr3.setPoints(3, xPos, topline, xPos, bottomline, xPos - 3, midline);
 			p.drawPolygon(cr3);
 
-			if (m_tabValues.count() != 0)
+			if (!m_tabValues.isEmpty())
 			{
 				p.setPen(QPen(textColor, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-				for (int yg = 0; yg < signed(m_tabValues.count()); yg++)
+				for (int yg = 0; yg < m_tabValues.count(); ++yg)
 				{
 					xPos = textPosToLocal(pos + m_tabValues[yg].tabPosition);
-					if (pos + m_tabValues[yg].tabPosition < endPos)
+					if (pos + m_tabValues[yg].tabPosition >= endPos)
+						continue;
+					switch (m_tabValues[yg].tabType)
 					{
-						switch (static_cast<int>(m_tabValues[yg].tabType))
-						{
-							case 0:
-								if (m_reverse)
-								{
-									p.save();
-									p.translate(pos + m_tabValues[yg].tabPosition, 0);
-									p.scale(-1, 1);
-									p.drawLine(0, tabline, 0, bottomline);
-									p.drawLine(0, bottomline, 8, bottomline);
-									p.restore();
-								}
-								else
-								{
-									p.drawLine(xPos, tabline, xPos, bottomline);
-									p.drawLine(xPos, bottomline, xPos+8, bottomline);
-								}
-								break;
-							case 1:
-								if (m_reverse)
-								{
-									p.save();
-									p.translate(pos + m_tabValues[yg].tabPosition, 0);
-									p.scale(-1, 1);
-									p.drawLine(0, tabline, 0, bottomline);
-									p.drawLine(0, bottomline, -8, bottomline);
-									p.restore();
-								}
-								else
-								{
-									p.drawLine(xPos, tabline, xPos, bottomline);
-									p.drawLine(xPos, bottomline, xPos-8, bottomline);
-								}
-								break;
-							case 2:
-							case 3:
+						case 0:
+							if (m_reverse)
+							{
+								p.save();
+								p.translate(pos + m_tabValues[yg].tabPosition, 0);
+								p.scale(-1, 1);
+								p.drawLine(0, tabline, 0, bottomline);
+								p.drawLine(0, bottomline, 8, bottomline);
+								p.restore();
+							}
+							else
+							{
 								p.drawLine(xPos, tabline, xPos, bottomline);
-								p.drawLine(xPos - 4, bottomline, xPos + 4, bottomline);
-								p.drawLine(xPos + 3, bottomline - 3, xPos + 2, bottomline - 3);
-								break;
-							case 4:
+								p.drawLine(xPos, bottomline, xPos + 8, bottomline);
+							}
+							break;
+						case 1:
+							if (m_reverse)
+							{
+								p.save();
+								p.translate(pos + m_tabValues[yg].tabPosition, 0);
+								p.scale(-1, 1);
+								p.drawLine(0, tabline, 0, bottomline);
+								p.drawLine(0, bottomline, -8, bottomline);
+								p.restore();
+							}
+							else
+							{
 								p.drawLine(xPos, tabline, xPos, bottomline);
-								p.drawLine(xPos - 4, bottomline, xPos + 4, bottomline);
-								break;
-							default:
-								break;
-						}
+								p.drawLine(xPos, bottomline, xPos - 8, bottomline);
+							}
+							break;
+						case 2:
+						case 3:
+							p.drawLine(xPos, tabline, xPos, bottomline);
+							p.drawLine(xPos - 4, bottomline, xPos + 4, bottomline);
+							p.drawLine(xPos + 3, bottomline - 3, xPos + 2, bottomline - 3);
+							break;
+						case 4:
+							p.drawLine(xPos, tabline, xPos, bottomline);
+							p.drawLine(xPos - 4, bottomline, xPos + 4, bottomline);
+							break;
+						default:
+							break;
 					}
 				}
 			}
@@ -587,7 +591,7 @@ void Hruler::paintEvent(QPaintEvent *e)
 }
 
 
-void Hruler::drawMarker(QPainter& p)
+void Hruler::drawMarker(QPainter& p) const
 {
 	// draw slim marker
 	QPolygon cr;
@@ -600,7 +604,7 @@ void Hruler::drawMarker(QPainter& p)
 }
 
 
-void Hruler::drawMarks(QPainter& p)
+void Hruler::drawMarks(QPainter& p) const
 {
 	const QPalette& palette = this->palette();
 	const QColor& textColor = palette.color(QPalette::Text);
@@ -659,7 +663,7 @@ void Hruler::drawMarks(QPainter& p)
 	}
 }	
 
-void Hruler::drawTextMarks(double pos, double endPos, QPainter& p)
+void Hruler::drawTextMarks(double pos, double endPos, QPainter& p) const
 {
 	double xl;
 	
@@ -678,7 +682,7 @@ void Hruler::drawTextMarks(double pos, double endPos, QPainter& p)
 		{
 			case SC_IN:
 				{
-					QString tx = "";
+					QString tx;
 					int num1 = static_cast<int>((xl - pos) / m_iter2 / m_cor);
 					if (num1 != 0)
 						tx = QString::number(num1);
@@ -692,84 +696,74 @@ void Hruler::drawTextMarks(double pos, double endPos, QPainter& p)
 					if (m_reverse)
 					{
 						p.save();
-						p.translate(xli - 2, 0);
+						p.translate(xli - 2.0, 0);
 						p.scale(-1, 1);
 						drawNumber(tx, 0, 17, p);
-						//p.drawText(0, 17, tx);
 						p.restore();
 					}
 					else
 						drawNumber(tx, xli + 2, 9, p);
-					//p.drawText(qRound((xl + 2 / sc) * sc), 9, tx);
 					break;
 				}
 			case SC_P:
 				if (m_reverse)
 				{
 					p.save();
-					p.translate(xli - 2, 0);
+					p.translate(xli - 2.0, 0);
 					p.scale(-1, 1);
 					drawNumber(QString::number((xl - pos) / m_iter / m_cor), 0, 17, p);
-					//p.drawText(0, 17, QString::number((xl - pos) / m_iter / m_cor));
 					p.restore();
 				}
 				else
 					drawNumber(QString::number((xl - pos) / m_iter / m_cor), xli + 2, 9, p);
-				//p.drawText(qRound((xl + 2 / sc) * sc), 9, QString::number((xl - pos) / m_iter / m_cor));
 				break;
 			case SC_CM:
 				if (m_reverse)
 				{
 					p.save();
-					p.translate(xli - 2, 0);
+					p.translate(xli - 2.0, 0);
 					p.scale(-1, 1);
 					drawNumber(QString::number((xl - pos) / m_iter / 10 / m_cor), 0, 9, p);
-					//p.drawText(0, 9, QString::number((xl - pos) / m_iter / 10 / m_cor));
 					p.restore();
 				}
 				else
 					drawNumber(QString::number((xl - pos) / m_iter / 10 / m_cor), xli + 2, 9, p);
-				//p.drawText(qRound((xl + 2 / sc) * sc), 9, QString::number((xl - pos) / m_iter / 10 / m_cor));
 				break;
 			case SC_C:
 				if (m_reverse)
 				{
 					p.save();
-					p.translate(xli - 2, 0);
+					p.translate(xli - 2.0, 0);
 					p.scale(-1, 1);
 					drawNumber(QString::number((xl - pos) / m_iter  / m_cor), 0, 9, p);
-					//p.drawText(0, 9, QString::number((xl - pos) / m_iter  / m_cor));
 					p.restore();
 				}
 				else
 					drawNumber(QString::number((xl - pos) / m_iter  / m_cor), xli + 2, 9, p);
-				//p.drawText(qRound((xl + 2 / sc) * sc), 9, QString::number((xl - pos) / m_iter  / m_cor));
 				break;
 			default:
 				if (m_reverse)
 				{
 					p.save();
-					p.translate(xli - 2, 0);
+					p.translate(xli - 2.0, 0);
 					p.scale(-1, 1);
 					drawNumber(QString::number((xl - pos) / m_iter * 10 / m_cor), 0, 9, p);
-					//p.drawText(0, 9, QString::number((xl - pos) / m_iter * 10 / m_cor));
 					p.restore();
 				}
 				else
 					drawNumber(QString::number((xl - pos) / m_iter * 10 / m_cor), xli + 2, 9, p);
-				//p.drawText(qRound((xl + 2 / sc) * sc), 9, QString::number((xl - pos) / m_iter * 10 / m_cor));
 				break;
 		}
 	}
 }
 
-void Hruler::drawNumber(const QString& txt, int x, int y0, QPainter & p)
+void Hruler::drawNumber(const QString& txt, int x, int y0, QPainter & p) const
 {
 	const int y = y0 - 3 + topline;
 	p.drawText(x,y,txt);
 }
 
-double Hruler::ruleSpacing()
+double Hruler::ruleSpacing() const
 {
 	return m_iter;
 }
@@ -811,9 +805,9 @@ void Hruler::setItem(PageItem * item)
 	const ParagraphStyle& currentStyle = item->currentStyle();
 	m_firstIndent = currentStyle.firstIndent();
 	m_leftMargin = currentStyle.leftMargin();
-	double columnWidth = (item->width() - (item->columnGap() * (item->columns() - 1))
+	double columnWidth = (item->width() - (item->columnGap() * (item->columns() - 1.0))
 						  - item->textToFrameDistLeft() - item->textToFrameDistLeft()
-						  - 2*m_lineCorr) / item->columns();
+						  - 2 * m_lineCorr) / item->columns();
 	m_rightMargin = columnWidth - currentStyle.rightMargin();
 	m_reverse = item->imageFlippedH();
 	m_textEditMode = true;
@@ -850,7 +844,7 @@ void Hruler::unitChange()
 {
 	double sc = m_view->scale();
 	m_cor = 1;
-	int docUnitIndex=m_doc->unitIndex();
+	int docUnitIndex = m_doc->unitIndex();
 	switch (docUnitIndex)
 	{
 		case SC_PT:
