@@ -36,7 +36,7 @@ public:
 	bool userActionOn(); // not yet implemented!!! This is needed badly.
                          // When user releases the mouse button or arrow key, changes must be checked
                          // and if in ScribusView a groupTransaction has been started it must be also
-                         // commmited
+                         // committed
 
 	void setLineMode(int lineMode);
 
@@ -106,7 +106,7 @@ protected:
 	
 	double m_oldRotation {0.0};
 
-	bool _userActionOn;
+	bool m_userActionOn { false };
 	UserActionSniffer *userActionSniffer;
 	void installSniffer(ScrSpinBox *spinBox);
 
