@@ -27,15 +27,14 @@ class SMRadioButton : public QRadioButton
 		void setChecked(bool val, bool isParentVal);
 
 		void setParentValue(bool);
-
 		bool useParentValue();
 
 	private:
-		bool m_hasParent;
-		bool m_useParentValue;
-		bool m_pValue;
-		void setFont(bool wantBold);
+		bool m_hasParent = false;
+		bool m_useParentValue = false;
+		bool m_pValue = false;
 
+		void setFont(bool wantBold);
 };
 
 
