@@ -7,10 +7,9 @@ for which a new license (GPL+exception) is in place.
 #ifndef SMSCCOMBOBOX_H
 #define SMSCCOMBOBOX_H
 
-#include "sccombobox.h"
+#include <QComboBox>
 
-
-class SMScComboBox  : public ScComboBox
+class SMScComboBox  : public QComboBox
 {
 	Q_OBJECT
 public:
@@ -32,13 +31,13 @@ public:
 	int getItemIndexForData(double d);
 	
 	void setParentItem(int i);
-
 	bool useParentValue();
 
 private:
-	bool   m_hasParent;
-	bool   m_useParentValue;
-	int    m_pItem;
+	bool   m_hasParent = false;
+	bool   m_useParentValue = false;
+	int    m_pItem = 0;
+
 	void setFont(bool wantBold);
 
 private slots:
