@@ -22,16 +22,16 @@ public:
 	void clear();
 
 	void setParentValue(int val);
-
 	bool useParentValue();
 
 protected:
 	void interpretText();
 
 private:
-	bool   m_hasParent;
-	bool   m_useParentValue;
-	int    m_pValue;
+	bool   m_hasParent = false;
+	bool   m_useParentValue = false;
+	int    m_pValue = 0;
+
 	void setFont(bool wantBold);
 
 private slots:
