@@ -73,6 +73,11 @@ old contents. */
 bool SCRIBUS_API loadRawText(const QString & filename, QByteArray & buf);
 bool SCRIBUS_API loadRawBytes(const QString & filename, QByteArray & buf);
 bool SCRIBUS_API loadRawBytes(const QString & filename, QByteArray & buf, int maxLength);
+/**
+ * @brief Split a string representing a command line into its arguments
+ * The code of this function is copied from Qt 5.15
+ */
+QStringList splitCommandLineArgs(const QString& command);
 /**
 * @brief Synchronously execute a new process, optionally saving its output
    *
@@ -126,7 +131,7 @@ QString SCRIBUS_API getLongPathName(const QString & shortPath);
    \retval QString standardized filename
    \author Petr Vanek
  */
-QString SCRIBUS_API getFileNameByPage(ScribusDoc* currDoc, uint pageNo, const QString& extension, const QString& prefix=QString());
+QString SCRIBUS_API getFileNameByPage(ScribusDoc* currDoc, uint pageNo, const QString& extension, const QString& prefix = QString());
 //asterix is QString used in numeration when number is presented as few chars, like *, **, *** etc
 //default is '*' but can be used any string
 QString getStringFromSequence(NumFormat type, uint position, const QString& asterix="*");
@@ -140,6 +145,7 @@ void SCRIBUS_API parsePagesString(const QString& pages, std::vector<int>* pageNs
 QString SCRIBUS_API readLineFromDataStream(QDataStream &s);
 void SCRIBUS_API setCurrentComboItem(QComboBox *box, const QString& text);
 void SCRIBUS_API setCurrentComboItemFromData(QComboBox *box, const QString& data);
+void SCRIBUS_API setCurrentComboItemFromData(QComboBox *box, quint64 data);
 void SCRIBUS_API removeComboItem(QComboBox *box, const QString& text);
 
 QString SCRIBUS_API readAdobeUniCodeString(QDataStream &s);
