@@ -18,10 +18,56 @@ for which a new license (GPL+exception) is in place.
 #include <QStringList>
 #include <QDataStream>
 #include <QByteArray>
+
 #include "util.h"
 #include "commonstrings.h"
-
+#include "prefscontext.h"
+#include "prefsfile.h"
+#include "prefsmanager.h"
 #include "scribuscore.h"
+#include "util_os.h"
+
+void PrinterUtil::getDefaultPrintOptions(PrintOptions& options, const MarginStruct& docBleeds)
+{
+	PrefsManager& prefsManager = PrefsManager::instance();
+	PrefsContext *prnPrefs = prefsManager.prefsFile->getContext("print_options");
+
+	options.firstUse = true;
+	options.printer  = prnPrefs->get("CurrentPrn", QString());
+	options.useAltPrintCommand = prnPrefs->getBool("OtherCom", false);
+	options.printerCommand = prnPrefs->get("Command", QString());
+	options.outputSeparations = prnPrefs->getInt("Separations", 0);
+	options.useColor = (prnPrefs->getInt("PrintColor", 0) == 0);
+	QStringList spots { "All" , "Cyan", "Magenta", "Yellow", "Black" };
+	int selectedSep  = prnPrefs->getInt("SepArt", 0);
+	if ((selectedSep < 0) || (selectedSep > 4))
+		selectedSep = 0;
+	options.separationName = spots.at(selectedSep);
+	if (prnPrefs->contains("PrintLanguage"))
+		options.prnLanguage = (PrintLanguage) prnPrefs->getInt("PrintLanguage", (int) PrinterUtil::getDefaultPrintLanguage(options.printer, false));
+	else
+		options.prnLanguage = (PrintLanguage) prnPrefs->getInt("PSLevel", (int) PrintLanguage::PostScript3);
+	options.mirrorH = prnPrefs->getBool("MirrorH", false);
+	options.mirrorV = prnPrefs->getBool("MirrorV", false);
+	options.setDevParam = prnPrefs->getBool("doDev", false);
+	options.doGCR   = prnPrefs->getBool("DoGCR", prefsManager.appPrefs.printerPrefs.GCRMode);
+	options.doClip  = prnPrefs->getBool("Clip", false);
+	options.useSpotColors = prnPrefs->getBool("doSpot", true);
+	options.useDocBleeds  = true;
+	options.bleeds = docBleeds;
+	options.markLength = prnPrefs->getDouble("markLength", 20.0);
+	options.markOffset = prnPrefs->getDouble("markOffset", 0.0);
+	options.cropMarks  = prnPrefs->getBool("cropMarks", false);
+	options.bleedMarks = prnPrefs->getBool("bleedMarks", false);
+	options.registrationMarks = prnPrefs->getBool("registrationMarks", false);
+	options.colorMarks = prnPrefs->getBool("colorMarks", false);
+	options.includePDFMarks = prnPrefs->getBool("includePDFMarks", true);
+}
+
+QString PrinterUtil::getDefaultPrinterName()
+{
+	return QPrinterInfo::defaultPrinterName();
+}
 
 QStringList PrinterUtil::getPrinterNames()
 {
@@ -83,73 +129,85 @@ bool PrinterUtil::initDeviceSettings(QString printerName, QByteArray& devModeA)
 }
 #endif
 
-bool PrinterUtil::getPrinterMarginValues(const QString& printerName, const QString& pageSize, double& ptsTopMargin, double& ptsBottomMargin, double& ptsLeftMargin, double& ptsRightMargin)
+bool PrinterUtil::getPrinterMarginValues(const QString& printerName, const QSizeF& pageSize, QMarginsF& margins)
 {
-	bool retVal = false;
 	QPrinterInfo pInfo = QPrinterInfo::printerInfo(printerName);
-	if (!pInfo.isNull())
+	if (pInfo.isNull())
+		return false;
+
+	QPrinter printer(pInfo, QPrinter::HighResolution);
+	margins = printer.pageLayout().margins();
+
+	// Unfortunately margin values are not updated when calling QPrinter or QPageLayout's setOrientation()
+	// so we have to adapt margin values according to orientation ourselves
+	if (pageSize.width() > pageSize.height())
 	{
-		QPrinter printer(pInfo, QPrinter::HighResolution);
-		QMarginsF margs = printer.pageLayout().margins(QPageLayout::Point);
-		ptsTopMargin = margs.top();
-		ptsBottomMargin = margs.bottom();
-		ptsLeftMargin = margs.left();
-		ptsRightMargin = margs.right();
-		retVal = true;
+		double l = margins.left();
+		double r = margins.right();
+		double b = margins.bottom();
+		double t = margins.top();
+		margins = QMarginsF(b, l, t, r);
 	}
-	return retVal;
+	return true;
 }
 
-PrintEngine PrinterUtil::getDefaultPrintEngine(const QString& printerName, bool toFile)
+PrintLanguage PrinterUtil::getDefaultPrintLanguage(const QString&  /*printerName*/, bool toFile)
 {
 	if (!toFile)
 	{
 #if defined(_WIN32)
-		return WindowsGDI;
+		return PrintLanguage::WindowsGDI;
 #else
-		return PostScript3;
+		return PrintLanguage::PostScript3;
 #endif
 	}
-	return PostScript3;
+	return PrintLanguage::PostScript3;
 }
 
-PrintEngineMap PrinterUtil::getPrintEngineSupport(const QString& printerName, bool toFile)
+PrintLanguageMap PrinterUtil::getPrintLanguageSupport(const QString& printerName, bool toFile)
 {
-	PrintEngineMap prnMap;
+	PrintLanguageMap prnMap;
 	if (toFile || PrinterUtil::isPostscriptPrinter(printerName))
 	{
 		if (ScCore->haveGS())
 		{
-			prnMap.insert(CommonStrings::trPostScript1, PostScript1);
-			prnMap.insert(CommonStrings::trPostScript2, PostScript2);
+			prnMap.insert(CommonStrings::trPostScript1, PrintLanguage::PostScript1);
+			prnMap.insert(CommonStrings::trPostScript2, PrintLanguage::PostScript2);
 		}
-		prnMap.insert(CommonStrings::trPostScript3, PostScript3);
+		prnMap.insert(CommonStrings::trPostScript3, PrintLanguage::PostScript3);
 	}
+	if (toFile || PrinterUtil::supportsPDF(printerName))
+		prnMap.insert(CommonStrings::trPDF, PrintLanguage::PDF);
 #if defined(_WIN32)
 	if (!toFile)
-		prnMap.insert(CommonStrings::trWindowsGDI, WindowsGDI);
+		prnMap.insert(CommonStrings::trWindowsGDI, PrintLanguage::WindowsGDI);
 #endif
 	return prnMap;
 }
 
-bool PrinterUtil::checkPrintEngineSupport(const QString& printerName, PrintEngine engine, bool toFile)
+bool PrinterUtil::checkPrintLanguageSupport(const QString& printerName, PrintLanguage engine, bool toFile)
 {
-	bool psSupported = toFile || PrinterUtil::isPostscriptPrinter(printerName);
-	if (psSupported && (engine >= PostScript1 && engine <= PostScript3))
-		return true;
-	if (!psSupported && (engine >= PostScript1 && engine <= PostScript3))
-		return false;
-	if (engine == WindowsGDI)
-	{
-#if defined(_WIN32)
-		return true; //WindowsGDI
-#else
-		return false;
-#endif
-	}
+	if (engine >= PrintLanguage::PostScript1 && engine <= PrintLanguage::PostScript3)
+		return (toFile || PrinterUtil::isPostscriptPrinter(printerName));
+
+	if (engine == PrintLanguage::WindowsGDI)
+		return os_is_win();
+
+	if (engine == PrintLanguage::PDF)
+		return toFile || os_is_unix();
+
 	return false;
 }
 
+bool PrinterUtil::supportsPDF(const QString& /*printerName*/)
+{
+#ifdef _WIN32
+	return false;
+#else
+	return true;
+#endif
+}
+
 //Parameter needed on win32..
 bool PrinterUtil::isPostscriptPrinter(const QString& printerName)
 {
